import { AlfrescoApi, SitesApi as SitesApi$1, UploadApi, NodesApi as NodesApi$1, PeopleApi, AdminUsersApi, AdminTenantsApi, GroupsApi, QueriesApi as QueriesApi$1, SearchApi, SecurityGroupsApi, SecurityMarksApi, SharedlinksApi, FavoritesApi, TrashcanApi as TrashcanApi$1, CommentsApi, CategoriesApi as CategoriesApi$1, TagsApi as TagsApi$1, ResultSetPaging, SharedLinkPaging, FavoritePaging, Site, SiteMemberEntry } from '@alfresco/js-api';
import { expect, chromium, devices, test as test$1 } from '@playwright/test';
import * as path from 'path';
import { resolve } from 'path';
import { format, endOfMonth, subMonths, subDays } from 'date-fns';
import StreamZip from 'node-stream-zip';
import * as fs from 'fs';
import fs__default from 'fs';
import * as crypto$1 from 'crypto';

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const rootFolder = 'e2e-output';
const paths = {
    rootFolder,
    allData: `${rootFolder}/playwright-data`,
    files: `${rootFolder}/playwright-data/downloads`,
    report: `${rootFolder}/playwright-data/report`,
    userStates: `${rootFolder}/playwright-data/user-states`
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const timeouts = {
    typingDelay: 50,
    tiny: 500,
    short: 1000,
    normal: 2000,
    medium: 5000,
    big: 7500,
    large: 10000,
    extraLarge: 20 * 1000,
    globalTest: 85 * 1000,
    extendedTest: 150 * 1000,
    extendedLongTest: 200 * 1000,
    webServer: 240 * 1000,
    globalSpec: 60 * 10 * 1000
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const getExcludedTestsRegExpArray = (excludedJson, projectName) => {
    const prefix = `[ 🎭 Playwright Excludes - ${projectName} ]`;
    const objectKeys = Object.keys(excludedJson);
    if (!objectKeys.length) {
        console.info(`${prefix} ✅ No excluded tests 🎉 `);
    }
    else {
        console.warn(`${prefix} ❌ Tests excluded because of 🐛 : ${objectKeys}`);
    }
    return objectKeys.map((key) => new RegExp(key));
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
function getUserState(user) {
    return resolve(process.cwd(), `${paths.userStates}/${user}UserState.json`);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const crypto = require('crypto');
class Utils {
    static string257Long = 'x'.repeat(257);
    static string513Long = 'x'.repeat(513);
    static random() {
        return crypto.getRandomValues(new Uint32Array(1))[0].toString(36).substring(0, 5).toLowerCase();
    }
    static retryCall(fn, retry = 30, delay = 1500) {
        const pause = (duration) => new Promise((res) => setTimeout(res, duration));
        const run = (retries) => {
            return fn().catch((err) => (retries > 1 ? pause(delay).then(() => run(retries - 1)) : Promise.reject(err)));
        };
        return run(retry);
    }
    static formatDate(date) {
        return new Date(date).toLocaleDateString('en-US');
    }
    /**
     * Method used to login user with navigation. Also waits for the page to load after login
     *
     * @param loginPage page context passed from the test
     * @param username username string
     * @param password password string
     * @param errorMessage error message string if the login fails
     *
     */
    static async tryLoginUser(loginPage, username, password, errorMessage = 'Error ') {
        try {
            await loginPage.loginUser({ username, password }, { withNavigation: true, waitForLoading: true });
        }
        catch (error) {
            console.error(`${errorMessage}: ${error}`);
        }
    }
    /**
     * Method used to delete nodes and sites from user's account
     *
     * @param nodesApi nodesApi initialized with user credentials passed from the test
     * @param trashcanApi trashcanApi initialized with user credentials passed from the test
     * @param errorMessage error message string if the deleting sites/nodes fails
     * @param sitesApi sitesApi initialized with user credentials passed from the test
     * @param sitesToDelete array of sites' ids
     *
     */
    static async deleteNodesSitesEmptyTrashcan(nodesApi, trashcanApi, errorMessage = 'Error ', sitesApi, sitesToDelete) {
        try {
            await nodesApi?.deleteCurrentUserNodes();
            await trashcanApi?.emptyTrashcan();
            if (sitesToDelete?.length > 0) {
                await sitesApi?.deleteSites(sitesToDelete);
            }
        }
        catch (error) {
            console.error(`${errorMessage}: ${error}`);
        }
    }
    static async uploadFileNewVersion(personalFilesPage, fileFromOS) {
        const fileInput = await personalFilesPage.page.$('#app-upload-file-version');
        await fileInput.setInputFiles(path.join(__dirname, `../resources/test-files/${fileFromOS}.docx`));
    }
    static async reloadPageIfRowNotVisible(pageContext, nodeName, errorMessage = 'reloadPageIfRowNotVisible Error ') {
        try {
            if (!(await pageContext.dataTable.getRowByName(nodeName).isVisible())) {
                await pageContext.page.reload({ waitUntil: 'load' });
            }
        }
        catch (error) {
            console.error(`${errorMessage}: ${error}`);
        }
    }
    static async reloadPageIfDatatableEmpty(pageContext, errorMessage = 'reloadPageIfDatatableEmpty Error ') {
        try {
            if ((await pageContext.dataTable.getEmptyFolderLocator.isVisible()) || (await pageContext.dataTable.emptyListTitle.isVisible())) {
                await pageContext.page.reload({ waitUntil: 'load' });
            }
        }
        catch (error) {
            console.error(`${errorMessage}: ${error}`);
        }
    }
    static getCurrentAndPreviousDay(currentDate = new Date()) {
        let formattedDate;
        let formattedDate2;
        const formatDate = (date) => {
            return format(date, 'dd-MMM-yy').toUpperCase();
        };
        if (currentDate.getDate() === 1) {
            const lastDayOfPreviousMonth = endOfMonth(subMonths(currentDate, 1));
            formattedDate = formatDate(lastDayOfPreviousMonth);
            formattedDate2 = formatDate(subDays(lastDayOfPreviousMonth, 1));
        }
        else {
            formattedDate = formatDate(currentDate);
            formattedDate2 = formatDate(subDays(currentDate, 1));
        }
        return { currentDate: formattedDate, previousDate: formattedDate2 };
    }
    static async verifyZipFileContent(filePath, fileOrFolderName) {
        const zip = new StreamZip({
            file: filePath,
            storeEntries: true
        });
        return new Promise((resolve) => {
            zip.on('ready', () => {
                const entries = zip.entries();
                const found = this.isFileOrFolderInEntries(entries, fileOrFolderName);
                zip.close();
                resolve(found);
            });
        });
    }
    static isFileOrFolderInEntries(entries, fileOrFolderName) {
        return fileOrFolderName.some((name) => {
            return Object.keys(entries).some((entry) => entry.includes(name));
        });
    }
    /**
     * Method used trim all elements of an array from all spaces characters
     *
     * @param arr array needed to be trimmed
     *
     */
    static trimArrayElements(arr) {
        return arr.map((element) => element.trim());
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const libraryErrors = {
    libraryIdIsNotAvailable: "This Library ID isn't available. Try a different Library ID.",
    libraryIdIsAlreadyUsed: 'This Library ID is already used. Check the trashcan.',
    useNumbersAndLettersOnly: 'Use numbers and letters only'
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const APP_ROUTES = {
    FAVORITES: '/favorites',
    MY_LIBRARIES: '/libraries',
    FAVORITE_LIBRARIES: '/favorite/libraries',
    LOGIN: '/login',
    LOGOUT: '/logout',
    PERSONAL_FILES: '/personal-files',
    RECENT_FILES: '/recent-files',
    SHARED_FILES: '/shared',
    TRASHCAN: '/trashcan'
};
const SIDEBAR_LABELS = {
    PERSONAL_FILES: 'Personal Files',
    MY_LIBRARIES: 'My Libraries',
    FAVORITE_LIBRARIES: 'Favorite Libraries',
    SHARED_FILES: 'Shared',
    RECENT_FILES: 'Recent Files',
    FAVORITES: 'Favorites',
    TRASH: 'Trash'
};
const SITE_ROLES = {
    SITE_MANAGER: {
        ROLE: 'SiteManager',
        LABEL: 'Manager'
    },
    SITE_CONSUMER: {
        ROLE: 'SiteConsumer',
        LABEL: 'Consumer'
    },
    SITE_CONTRIBUTOR: {
        ROLE: 'SiteContributor',
        LABEL: 'Contributor'
    },
    SITE_COLLABORATOR: {
        ROLE: 'SiteCollaborator',
        LABEL: 'Collaborator'
    },
    NONE: {
        LABEL: 'Not a member'
    }
};
const SITE_VISIBILITY = {
    PUBLIC: 'PUBLIC',
    MODERATED: 'MODERATED',
    PRIVATE: 'PRIVATE'
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const errorStrings = {
    errorMessageNotPresent: 'Error message is not displayed',
    nameIsRequiredError: 'Name is required',
    nameWithSpecialCharactersError: `Name can't contain these characters * " < > \\ / ? : |`,
    nameEndWithDotError: `Name can't end with a period .`,
    nameContainOnlySpacesError: `Name can't contain only spaces`,
    titleLengthLimitError: 'Use 256 characters or less for title',
    descriptionLengthLimitError: 'Use 512 characters or less for description',
    nameAlreadyUsedError: 'This name is already in use, try a different name.',
    folderNameIsRequired: 'Folder name is required',
    folderNameCantEndWithAPeriod: `Folder name can't end with a period .`,
    folderNameCantContainTheseCharacters: `Folder name can't contain these characters`,
    folderNameCantContainOnlySpaces: `Folder name can't contain only spaces`,
    thereIsAlreadyAFolderWithThisName: `There's already a folder with this name. Try a different name.`
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
async function waitForApi(apiCall, predicate, retry = 30, delay = 1000) {
    const apiCallWithPredicateChecking = async () => {
        const apiCallResult = await apiCall();
        if (predicate(apiCallResult)) {
            return Promise.resolve(apiCallResult);
        }
        else {
            return Promise.reject(new Error(`API call did not satisfy predicate: ${JSON.stringify(apiCallResult)}`));
        }
    };
    return retryCall(apiCallWithPredicateChecking, retry, delay);
}
function retryCall(fn, retry = 30, delay = 1000) {
    const pause = (duration) => new Promise((res) => setTimeout(res, duration));
    const run = (retries) => fn().catch((err) => retries > 1
        ? pause(delay).then(() => run(retries - 1))
        : Promise.reject(new Error(`API call did not satisfy predicate: ${JSON.stringify(err)}`)));
    return run(retry);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
/* eslint-disable @typescript-eslint/naming-convention */
const infoColor = '\x1b[36m%s\x1b[0m';
const logColor = '\x1b[35m%s\x1b[0m';
const warnColor = '\x1b[33m%s\x1b[0m';
const errorColor = '\x1b[31m%s\x1b[0m';
class LogLevelsEnum extends Number {
    static TRACE = 5;
    static DEBUG = 4;
    static INFO = 3;
    static WARN = 2;
    static ERROR = 1;
    static SILENT = 0;
}
const logLevels = [
    { level: LogLevelsEnum.TRACE, name: 'TRACE' },
    { level: LogLevelsEnum.DEBUG, name: 'DEBUG' },
    { level: LogLevelsEnum.INFO, name: 'INFO' },
    { level: LogLevelsEnum.WARN, name: 'WARN' },
    { level: LogLevelsEnum.ERROR, name: 'ERROR' },
    { level: LogLevelsEnum.SILENT, name: 'SILENT' }
];
/* eslint-disable no-console */
class GenericLogger {
    level;
    constructor(logLevel) {
        this.level = logLevels.find(({ name }) => name === logLevel)?.level || LogLevelsEnum.ERROR;
    }
    info(...messages) {
        if (Number(this.level) >= LogLevelsEnum.INFO) {
            console.log(infoColor, messages.join(''));
        }
    }
    log(...messages) {
        if (Number(this.level) >= LogLevelsEnum.TRACE) {
            console.log(logColor, messages.join(''));
        }
    }
    warn(...messages) {
        if (Number(this.level) >= LogLevelsEnum.WARN) {
            console.log(warnColor, messages.join(''));
        }
    }
    error(...messages) {
        console.log(errorColor, messages.join(''));
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class PlaywrightBase {
    page;
    logger;
    constructor(page) {
        this.page = page;
        this.logger = new GenericLogger(process.env.PLAYWRIGHT_CUSTOM_LOG_LEVEL);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseComponent extends PlaywrightBase {
    rootElement;
    overlayElement = this.page.locator('.cdk-overlay-backdrop-showing');
    progressBar = this.page.locator('mat-progress-bar');
    constructor(page, rootElement) {
        super(page);
        this.rootElement = rootElement;
    }
    /**
     * Method which should be used across the repository, while creating
     * reference to elements, which are in root element of component.
     *
     * @param cssLocator css selector as String. Need to be in the tree under the root element
     * @param options if you want to localize it by text, then provide an optional hasText
     * @returns Locator object
     */
    getChild(cssLocator, options) {
        return this.page.locator(`${this.rootElement} ${cssLocator}`, options);
    }
    async closeAdditionalOverlayElementIfVisible() {
        if (await this.overlayElement.isVisible()) {
            await this.page.keyboard.press('Escape');
            await this.overlayElement.waitFor({ state: 'detached', timeout: timeouts.medium });
        }
    }
    async spinnerWaitForReload() {
        try {
            await this.page.locator('mat-progress-spinner').waitFor({ state: 'attached', timeout: timeouts.medium });
            await this.page.locator('mat-progress-spinner').waitFor({ state: 'detached', timeout: timeouts.normal });
        }
        catch (e) {
            this.logger.info('Spinner was not present');
        }
    }
    async progressBarWaitForReload() {
        try {
            await this.progressBar.waitFor({ state: 'visible', timeout: timeouts.medium });
            await this.progressBar.waitFor({ state: 'hidden', timeout: timeouts.normal });
        }
        catch (e) {
            this.logger.info('Progress bar was not present');
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SnackBarComponent extends BaseComponent {
    static rootElement = 'adf-snackbar-content';
    message = this.getChild('[data-automation-id="adf-snackbar-message-content"]').first();
    actionButton = this.getChild('[data-automation-id="adf-snackbar-message-content-action-button"]');
    closeIcon = this.getChild('.adf-snackbar-message-content-action-icon');
    getByMessageLocator = (message) => this.getChild(`[data-automation-id='adf-snackbar-message-content']`, { hasText: message }).first();
    constructor(page, rootElement = SnackBarComponent.rootElement) {
        super(page, rootElement);
    }
    async getSnackBarMessage() {
        return this.message.textContent();
    }
    async getSnackBarActionText() {
        if (await this.actionButton.isVisible()) {
            return this.actionButton.textContent();
        }
        else {
            return '';
        }
    }
    async verifySnackBarActionText(text) {
        expect(await this.message.textContent()).toContain(text);
    }
    async clickSnackBarAction() {
        await this.actionButton.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class MatMenuComponent extends BaseComponent {
    static rootElement = '.mat-mdc-menu-content';
    constructor(page) {
        super(page, MatMenuComponent.rootElement);
    }
    getMenuItemsLocator = this.getChild('button');
    getMenuItemTextLocator = this.getChild('[data-automation-id="menu-item-title"]');
    createFolder = this.getChild('[id="app.create.folder"]');
    createFolderFromTemplate = this.getChild('[id="app.create.folderFromTemplate"]');
    createFileFromTemplate = this.getChild('[id="app.create.fileFromTemplate"]');
    createLibrary = this.getChild('[id="app.create.library"]');
    getButtonByText = (text) => this.getChild('button', { hasText: text });
    getMenuItemFromHeaderMenu = (text) => this.page.getByRole('menuitem', { name: text, exact: true });
    async clickMenuItem(menuItem) {
        const menuElement = this.getButtonByText(menuItem);
        await menuElement.click();
        await menuElement.waitFor({ state: 'detached' });
    }
    async clickMenuItemFromHeaderMenu(menuItem) {
        const menuElement = this.getMenuItemFromHeaderMenu(menuItem);
        await menuElement.click();
        await menuElement.waitFor({ state: 'detached' });
    }
    async isMenuItemVisible(menuItem) {
        const menuElement = this.getButtonByText(menuItem);
        await menuElement.waitFor({ state: 'attached' });
        return menuElement.isVisible();
    }
    async verifyActualMoreActions(expectedToolbarMore) {
        await this.page.locator('.mat-mdc-menu-content').waitFor({ state: 'attached' });
        const menus = await this.page.$$('.mat-mdc-menu-content .mat-mdc-menu-item');
        const actualMoreActions = await Promise.all(menus.map(async (button) => {
            const title = await (await button.$('.mat-mdc-menu-item-text span')).innerText();
            return title || '';
        }));
        for (const action of expectedToolbarMore) {
            expect(actualMoreActions.includes(action), `Expected to contain ${action} ${actualMoreActions}`).toBe(true);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
var PaginationActionsType;
(function (PaginationActionsType) {
    PaginationActionsType["PageSizeSelector"] = "Page size selector";
    PaginationActionsType["CurrentPageSelector"] = "Current page selector";
    PaginationActionsType["NextPageSelector"] = "Next page button";
})(PaginationActionsType || (PaginationActionsType = {}));
class PaginationComponent extends BaseComponent {
    static rootElement = 'adf-pagination';
    constructor(page) {
        super(page, PaginationComponent.rootElement);
    }
    range = this.getChild('.adf-pagination__range');
    maxItems = this.getChild('.adf-pagination__max-items');
    currentPage = this.getChild('.adf-pagination__current-page');
    totalPages = this.getChild('.adf-pagination__total-pages');
    previousButton = this.getChild('.adf-pagination__previous-button');
    nextButton = this.getChild('.adf-pagination__next-button');
    maxItemsButton = this.getChild('.adf-pagination__max-items + button[mat-icon-button]');
    itemsPerPageMenu = new MatMenuComponent(this.page);
    currentPageLocator = this.getChild('.adf-pagination__current-page');
    totalPageLocator = this.getChild('.adf-pagination__total-pages');
    getArrowLocatorFor = (action) => this.getChild(`[aria-label="${action}"]`);
    async setItemsPerPage(amount) {
        await this.getArrowLocatorFor(PaginationActionsType.PageSizeSelector).click();
        await this.itemsPerPageMenu.getButtonByText(amount.toString()).click();
        await this.spinnerWaitForReload();
    }
    async navigateToPage(pageNumber) {
        await this.getArrowLocatorFor(PaginationActionsType.CurrentPageSelector).click();
        await this.itemsPerPageMenu.getButtonByText(pageNumber.toString()).click();
        await this.spinnerWaitForReload();
    }
    async spinnerWaitForReload() {
        try {
            await this.page.locator('mat-progress-spinner').waitFor({ state: 'attached', timeout: 2000 });
            await this.page.locator('mat-progress-spinner').waitFor({ state: 'detached', timeout: 2000 });
        }
        catch (e) {
            this.logger.info('Spinner was not present');
        }
    }
    async getRange() {
        return this.range.innerText();
    }
    async getMaxItems() {
        return this.maxItems.innerText();
    }
    async getCurrentPage() {
        return this.currentPage.innerText();
    }
    async getTotalPages() {
        return this.totalPages.innerText();
    }
    async isPreviousEnabled() {
        return this.previousButton.isEnabled();
    }
    async isNextEnabled() {
        await this.page.waitForTimeout(timeouts.tiny);
        return this.nextButton.isEnabled();
    }
    async clickOnNextPage() {
        try {
            if (await this.isNextEnabled()) {
                await this.nextButton.click();
            }
        }
        catch (error) {
            throw new Error(`Failed on previous click: ${error}`);
        }
    }
    async clickOnPreviousPage() {
        try {
            if (await this.isPreviousEnabled()) {
                await this.previousButton.click();
            }
        }
        catch (error) {
            throw new Error(`Failed on previous click: ${error}`);
        }
    }
    async openMaxItemsMenu() {
        try {
            await this.maxItemsButton.waitFor({ state: 'visible' });
            await this.maxItemsButton.click();
        }
        catch (error) {
            throw new Error(`Open max items catch: ${error}`);
        }
    }
    async resetToDefaultPageSize() {
        try {
            await this.openMaxItemsMenu();
            await this.clickNthItem(1);
            await this.page.waitForTimeout(timeouts.tiny);
        }
        catch (error) {
            throw new Error(`Reset to default page size catch: ${error}`);
        }
    }
    async clickMenuItem(menuItem) {
        try {
            await this.page.getByRole('menuitem', { name: menuItem }).click();
        }
        catch (e) {
            throw new Error(`Click menu item catch : failed to click on: ${e}`);
        }
    }
    async getNthItem(nth) {
        return this.page.getByRole('menuitem').nth(nth - 1);
    }
    async getItemsCount() {
        return this.page.getByRole('menuitem').count();
    }
    async clickNthItem(nth) {
        try {
            await (await this.getNthItem(nth)).click();
        }
        catch (e) {
            throw new Error(`Click nth menu item catch: ${e}`);
        }
    }
    async closeMenu() {
        await this.page.keyboard.press('Escape');
    }
    async isRangePresent() {
        return this.range.isVisible();
    }
    async getMaxRange() {
        return this.range.textContent();
    }
    async isMaxItemsPresent() {
        return this.maxItems.isVisible();
    }
    async isCurrentPagePresent() {
        return this.currentPage.isVisible();
    }
    async isTotalPagesPresent() {
        return this.totalPages.isVisible();
    }
    async isPreviousButtonPresent() {
        return this.previousButton.isVisible();
    }
    async isNextButtonPresent() {
        return this.nextButton.isVisible();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class DataTableComponent extends BaseComponent {
    static rootElement = 'adf-datatable';
    contextMenuActions = new MatMenuComponent(this.page);
    constructor(page, rootElement = DataTableComponent.rootElement) {
        super(page, rootElement);
    }
    pagination = new PaginationComponent(this.page);
    body = this.getChild('.adf-datatable-body');
    getEmptyFolderLocator = this.getChild('.adf-empty-folder');
    getEmptyContentTitleLocator = this.getChild('adf-empty-content .adf-empty-content__title');
    getEmptyContentSubTitleLocator = this.getChild('adf-empty-content .adf-empty-content__subtitle');
    getSelectedRow = this.getChild('.adf-datatable-row.adf-is-selected');
    sortedColumnHeader = this.getChild(`.adf-datatable__header--sorted-asc .adf-datatable-cell-header-content .adf-datatable-cell-value,
                                      .adf-datatable__header--sorted-desc .adf-datatable-cell-header-content .adf-datatable-cell-value`);
    columnHeaders = this.getChild('.adf-datatable-row .adf-datatable-cell-header .adf-datatable-cell-value');
    emptyList = this.getChild('div.adf-no-content-container');
    emptyListTitle = this.getChild('.adf-empty-content__title');
    emptyListSubtitle = this.getChild('.adf-empty-content__subtitle');
    emptySearchText = this.getChild('.empty-search__text');
    emptyListTest = this.getChild('adf-custom-empty-content-template');
    paginationButton = this.page.locator('.adf-pagination__block button').nth(0);
    paginationOptions = this.page.locator('#cdk-overlay-0 button');
    sitesVisibility = this.page.locator('.adf-datatable-body [data-automation-id*="datatable-row"] [aria-label="Visibility"]');
    sitesName = this.page.locator('.adf-datatable-body [data-automation-id*="datatable-row"] [aria-label="Name"]');
    sitesRole = this.page.locator('.adf-datatable-body [data-automation-id*="datatable-row"] [aria-label="My Role"]');
    lockOwner = this.page.locator('.aca-locked-by--name');
    uncheckedCheckbox = this.page.locator('.mat-mdc-checkbox');
    checkedCheckbox = this.page.locator('.mat-mdc-checkbox-checked');
    highlightedText = '.aca-highlight';
    searchFileName = '.search-file-name';
    searchFileDescription = '[data-automation-id="search-results-entry-description"]';
    searchFileContent = '.aca-result-content';
    /** Locator for row (or rows) */
    getRowLocator = this.page.getByRole('rowgroup').nth(1).locator('adf-datatable-row');
    /** Locator to get "No results found" message */
    getNoResultsFoundMessage = this.getChild('adf-custom-empty-content-template', { hasText: 'No results found' });
    /**
     * Method used in cases where we want to check that some record is visible in the datatable. It will consider whole row
     *
     * @returns reference to cell element which contains text.
     */
    getRowByName = (name) => this.getChild(`adf-datatable-row`, { hasText: name.toString() });
    /**
     * Method used in cases where we want to check that some record is visible in the datatable.
     * But we want to check it by column header title and value of this column.
     *
     * @returns reference to cell element which contains text.
     */
    getRowByColumnTitleAndItsCellValue = (columnTitle, cellValue) => this.page.locator(`//div[contains(@title, '${columnTitle}')]//span[contains(text(), '${cellValue}')]/ancestor::adf-datatable-row`);
    /**
     * Method used in cases where we want to retrieve a row from the datatable based on its numerical order within the array.
     *
     * @returns reference to cell element which contains text.
     */
    getNthRow = (orderNum) => this.getRowLocator.nth(orderNum);
    /**
     * Method used in cases where user have possibility to navigate "inside" the element (it's clickable and has link attribute).
     * Perform action .click() to navigate inside it
     *
     * @returns reference to cell element which contains link.
     */
    getCellLinkByName = (name) => this.getChild('.adf-cell-value span[role="link"]', { hasText: name });
    /**
     * Method used in cases where we want to localize the element by [aria-label]
     *
     * @returns reference to cell element.
     */
    getByAriaLabelTitle = (title) => this.getChild(`[aria-label="${title}"]`);
    /**
     * Method used in cases where we want to get the button (hamburger menu) for row element
     *
     * @returns reference to menu placed in row localized by the name
     */
    getActionsButtonByName = (name) => this.getRowByName(name).locator('mat-icon', { hasText: new RegExp(`^\\s*more_vert\\s*$`, 'g') });
    /**
     * Method used in cases where we want to get the edit button and there is no hamburger menu
     *
     * @returns reference to edit button placed in row localized by the name
     */
    getEditButtonByName = (name) => this.getRowByName(name).locator('button#editButton');
    /**
     * Method used in cases where we want to get the button and there is no hamburger menu
     *
     * @returns reference to button placed in row localized by the name
     */
    getButtonByNameForSpecificRow = (elementTitleInRow, buttonTitle) => this.getRowByName(elementTitleInRow).locator('button', { hasText: buttonTitle });
    /**
     * Method used in cases where you want to get some specific cell (by column name) for row which contains some name/title/etc.
     *
     * @returns reference to cell element
     */
    getCellByColumnNameAndRowItem = (item, columnName) => this.getRowByName(item).locator(`[title="${columnName}"]`);
    /**
     * Method used in cases where we want to get the checkbox for row element
     *
     * @returns reference to checkbox placed in row localized by the name
     */
    getCheckboxForElement = (item) => this.getRowByName(item).locator('.mat-mdc-checkbox');
    getColumnHeaderByTitleLocator = (headerTitle) => this.getChild('[role="columnheader"]', { hasText: headerTitle });
    getSearchResultLinkByName = (name) => this.getChild('.aca-search-results-row span[role="link"]', { hasText: name });
    getColumnValuesByName = (name) => this.getChild(`div[title="${name}"] span`);
    getColumnHeaderByName = (headerTitle) => this.getChild('.adf-datatable-row .adf-datatable-cell-header .adf-datatable-cell-value', { hasText: headerTitle });
    async sortBy(label, order) {
        const sortColumn = await this.getSortedColumnHeaderText();
        let sortOrder = await this.getSortingOrder();
        if (sortColumn !== label) {
            await this.getColumnHeaderByName(label).hover();
            await this.getColumnHeaderByName(label).click({ force: true });
            sortOrder = await this.getSortingOrder();
        }
        if (sortOrder !== order) {
            await this.getChild('span[class*="adf-datatable__header--sorted"]').click();
        }
    }
    /**
     * This method is used when we want to perform right mouse click on the dataTable row and perform some action
     *
     * @param name of the data table element with which we want to click
     * @param action provide which action you want to perform
     */
    async performActionFromExpandableMenu(name, action) {
        await this.goThroughPagesLookingForRowWithName(name);
        const actionButtonLocator = await this.getActionLocatorFromExpandableMenu(name, action);
        await actionButtonLocator.click();
        await this.spinnerWaitForReload();
    }
    /**
     * Click action from the expandable kebab menu for the element in datatable
     *
     * @param name title of the record you would like to proceed
     * @param action provide button title for the action
     * @param subAction if the action is in sub menu, then provide it here
     */
    async performActionForElement(name, action, subAction) {
        await this.getActionsButtonByName(name).click();
        await this.contextMenuActions.getButtonByText(action).click();
        if (subAction) {
            await this.contextMenuActions.getButtonByText(subAction).click();
        }
    }
    /**
     * This method is used when we want to perform double click on the dataTable row to open a file or folder
     *
     * @param name of the data table element with which we want to double click
     */
    async performClickFolderOrFileToOpen(name) {
        await this.getCellLinkByName(name).click();
        await this.spinnerWaitForReload();
    }
    async isItemPresent(name) {
        await this.goThroughPagesLookingForRowWithName(name);
        return this.getRowByName(name).isVisible();
    }
    async getActionLocatorFromExpandableMenu(name, action) {
        await this.getRowByName(name).click({ button: 'right' });
        return this.contextMenuActions.getButtonByText(action);
    }
    async performActionInExpandableMenu(name, action) {
        await this.getRowByName(name).click({ button: 'right' });
        await this.contextMenuActions.getButtonByText(action).click();
    }
    async goThroughPagesLookingForRowWithName(name) {
        await this.spinnerWaitForReload();
        if (await this.getRowByName(name).isVisible()) {
            return null;
        }
        if (await this.pagination.currentPageLocator.isVisible()) {
            if ((await this.pagination.currentPageLocator.textContent()) === ' of 1 ') {
                return null;
            }
        }
        if (await this.pagination.totalPageLocator.isVisible()) {
            const maxPages = (await this.pagination.totalPageLocator?.textContent())?.match(/\d/)[0];
            for (let page = 1; page <= Number(maxPages); page++) {
                if (await this.getRowByName(name).isVisible()) {
                    break;
                }
                if (await this.pagination.getArrowLocatorFor(PaginationActionsType.NextPageSelector).isEnabled()) {
                    await this.pagination.getArrowLocatorFor(PaginationActionsType.NextPageSelector).click();
                }
                await this.spinnerWaitForReload();
            }
        }
    }
    async selectItems(...names) {
        for (const name of names) {
            const isSelected = await this.isRowSelected(name);
            if (!isSelected) {
                const row = this.getRowByName(name);
                await row.hover();
                await row.locator(this.uncheckedCheckbox).click();
                await row.locator(this.checkedCheckbox).waitFor({ state: 'attached' });
            }
        }
    }
    async isRowSelected(itemName) {
        const row = this.getRowByName(itemName);
        return row.locator(this.checkedCheckbox).isVisible();
    }
    async getColumnHeaders() {
        const columnNameLocator = this.columnHeaders;
        await this.columnHeaders.nth(0).waitFor({ state: 'attached' });
        return columnNameLocator.allTextContents();
    }
    async getSortedColumnHeaderText() {
        return this.sortedColumnHeader.innerText();
    }
    getItemLocationEl(name) {
        return this.getRowByName(name).locator('.aca-location-link');
    }
    async getItemLocationText(name) {
        await this.getItemLocationEl(name).locator('a').waitFor({ state: 'attached' });
        return this.getItemLocationEl(name).innerText();
    }
    async getItemLocationTooltip(name) {
        const location = this.getItemLocationEl(name);
        await location.hover();
        return location.locator('a').getAttribute('title', { timeout: timeouts.normal });
    }
    async clickItemLocation(name) {
        await this.getItemLocationEl(name).click();
    }
    async getSortingOrder() {
        const str = await this.sortedColumnHeader.locator('../..').getAttribute('class');
        if (str.includes('asc')) {
            return 'asc';
        }
        else if (str.includes('desc')) {
            return 'desc';
        }
        return 'none';
    }
    async getRowAllInnerTexts(name) {
        return (await this.getRowByName(name).locator('span').allInnerTexts()).toString();
    }
    async getFirstElementDetail(name) {
        const firstNode = this.getColumnValuesByName(name).first();
        return firstNode.innerText();
    }
    async isEmpty() {
        return this.emptyList.isVisible();
    }
    async getEmptyStateTitle() {
        return (await this.isEmpty()) ? this.emptyListTitle.innerText() : '';
    }
    async getEmptyStateSubtitle() {
        return (await this.isEmpty()) ? this.emptyListSubtitle.innerText() : '';
    }
    async getEmptyListText() {
        return (await this.isEmpty()) ? this.emptyListTest.innerText() : '';
    }
    async getRowsCount() {
        return this.getRowLocator.count();
    }
    async rightClickOnItem(itemName) {
        await this.getCellByColumnNameAndRowItem(itemName, 'Name').click({ button: 'right' });
    }
    async setPaginationTo50() {
        await this.paginationButton.click();
        await this.paginationOptions.getByText('50').click();
    }
    /**
     * Method used to create objects from names and visibility of sites from datatable
     *
     * @returns an object with sites' names and their corresponding visibility values
     */
    async getSitesNameAndVisibility() {
        const rowsCount = await this.sitesName.count();
        const sitesInfo = {};
        for (let i = 0; i < rowsCount; i++) {
            let siteVisibilityText = await this.sitesVisibility.nth(i).textContent();
            let siteNameText = await this.sitesName.nth(i).textContent();
            siteVisibilityText = siteVisibilityText.trim().toUpperCase();
            siteNameText = siteNameText.trim();
            sitesInfo[siteNameText] = siteVisibilityText;
        }
        return sitesInfo;
    }
    /**
     * Method used to create objects from names and roles of sites from datatable
     *
     * @returns an object with sites' names and their corresponding role values
     */
    async getSitesNameAndRole() {
        const rowsCount = await this.sitesName.count();
        const sitesInfo = {};
        for (let i = 0; i < rowsCount; i++) {
            let siteNameText = await this.sitesName.nth(i).textContent();
            let siteRoleText = await this.sitesRole.nth(i).textContent();
            siteNameText = siteNameText.trim();
            siteRoleText = siteRoleText.trim();
            sitesInfo[siteNameText] = siteRoleText;
        }
        return sitesInfo;
    }
    async hasLockIcon(itemName) {
        const row = this.getRowByName(itemName);
        return row.locator('img[src*="lock"]').isVisible();
    }
    async getLockOwner(itemName) {
        const row = this.getRowByName(itemName);
        return row.locator(this.lockOwner).innerText();
    }
    async hasHighlightedText(location) {
        switch (location) {
            case 'name':
                return this.page.locator(this.searchFileName).locator(this.highlightedText).isVisible();
            case 'description':
                return this.page.locator(this.searchFileDescription).locator(this.highlightedText).isVisible();
            case 'content':
                return this.page.locator(this.searchFileContent).locator(this.highlightedText).isVisible();
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ToolbarComponent extends BaseComponent {
    static rootElement = 'adf-toolbar';
    createRuleButton = this.getChild('[data-automation-id="manage-rules-create-button"]');
    linkRulesButton = this.getChild('[data-automation-id="manage-rules-link-button"]');
    constructor(page) {
        super(page, ToolbarComponent.rootElement);
    }
    async clickCreateRuleButton() {
        await this.createRuleButton.click();
    }
    async clickLinkRulesButton() {
        await this.linkRulesButton.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AdfFolderDialogComponent extends BaseComponent {
    static rootElement = 'adf-folder-dialog';
    folderNameInputLocator = this.getChild('[id="adf-folder-name-input"]');
    folderNameInputHint = this.getChild('mat-hint');
    folderTitleInput = this.getChild('[id="adf-folder-title-input"]');
    folderDescriptionInput = this.getChild('[id="adf-folder-description-input"]');
    createButton = this.getChild('[id="adf-folder-create-button"]');
    cancelButton = this.getChild('[id="adf-folder-cancel-button"]');
    constructor(page) {
        super(page, AdfFolderDialogComponent.rootElement);
    }
    getLabelText = (text) => this.getChild('label', { hasText: text });
    getRequiredMarker = (text) => this.getLabelText(text).locator('.mat-mdc-form-field-required-marker');
    /**
     * This method is used when we want to fill in Create new Folder Dialog and choose Create button
     *
     * @param nameInput input for the Name field
     * @param titleInput input for Title field
     * @param descriptionInput input for Description field
     */
    async createNewFolderDialog(nameInput, titleInput, descriptionInput) {
        await this.folderNameInputLocator.fill(nameInput);
        if (titleInput) {
            await this.folderTitleInput.fill(titleInput);
        }
        if (descriptionInput) {
            await this.folderDescriptionInput.fill(descriptionInput);
        }
        await this.createButton.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AdfLibraryDialogComponent extends BaseComponent {
    static rootElement = 'adf-library-dialog';
    createButton = this.getChild('[data-automation-id="create-library-id"]');
    cancelButton = this.getChild('[data-automation-id="cancel-library-id"]');
    constructor(page) {
        super(page, AdfLibraryDialogComponent.rootElement);
    }
    getLabelText = (text) => this.getChild('label', { hasText: text });
    getRequiredMarker = (text) => this.getLabelText(text).locator('.mat-mdc-form-field-required-marker');
    getDialogTitle = (text) => this.getChild('.mat-mdc-dialog-title', { hasText: text });
    getErrorByText = (text) => this.page.locator('mat-error', { hasText: text });
    /**
     * This method is used when we want to fill in Create Library Dialog and choose Create button
     *
     * @param nameInput input for the Name field
     * @param libraryIdInput input for Library ID field
     * @param descriptionInput input for Description field
     * @param visibility visibility of the library
     */
    async createLibraryWithNameAndId(nameInput, libraryIdInput, descriptionInput, visibility) {
        await this.getLabelText('Name').fill(nameInput);
        await this.getLabelText('Library ID').clear();
        await this.getLabelText('Library ID').fill(libraryIdInput);
        if (descriptionInput) {
            await this.getLabelText('Description').fill(descriptionInput);
        }
        if (visibility) {
            await this.getLabelText(visibility).click();
        }
        await this.createButton.click();
        await this.spinnerWaitForReload();
    }
    async isErrorMessageDisplayed(errorText) {
        await this.getErrorByText(errorText).waitFor({ state: 'visible', timeout: timeouts.large });
        return this.getErrorByText(errorText).isVisible();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class PasswordOverlayDialogComponent extends BaseComponent {
    static rootElement = '.cdk-overlay-pane';
    closeButton = this.getChild('[data-automation-id="adf-password-dialog-close"]');
    submitButton = this.getChild('[data-automation-id="adf-password-dialog-submit"]');
    passwordInput = this.getChild('[data-automation-id="adf-password-dialog-input"]');
    errorMessage = this.getChild('[data-automation-id="adf-password-dialog-error"]');
    constructor(page, rootElement = PasswordOverlayDialogComponent.rootElement) {
        super(page, rootElement);
    }
    async waitForDialogToOpen() {
        await this.spinnerWaitForReload();
        await this.passwordInput.waitFor({ state: 'attached', timeout: timeouts.large });
        await this.passwordInput.isVisible();
    }
    async waitForDialogToClose() {
        await this.passwordInput.waitFor({ state: 'detached', timeout: timeouts.large });
    }
    async isDialogOpen() {
        await this.waitForDialogToOpen();
        return this.passwordInput.isVisible();
    }
    async isCloseVisible() {
        return this.closeButton.isVisible();
    }
    async isSubmitHidden() {
        return this.submitButton.isHidden();
    }
    async isPasswordInputDisplayed() {
        return this.passwordInput.isVisible();
    }
    async isErrorDisplayed() {
        await this.errorMessage.waitFor({ state: 'visible', timeout: timeouts.short });
        return this.errorMessage.isVisible();
    }
    async getErrorMessage() {
        if (await this.isErrorDisplayed()) {
            return this.errorMessage.innerText();
        }
        return '';
    }
    async enterPassword(password) {
        await this.passwordInput.fill(password);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ViewerOverlayDialogComponent extends BaseComponent {
    static rootElement = '.cdk-overlay-pane';
    closeButton = this.getChild('[data-automation-id="adf-password-dialog-close"]');
    submitButton = this.getChild('[data-automation-id="adf-password-dialog-submit"]');
    passwordInput = this.getChild('[data-automation-id="adf-password-dialog-input"]');
    errorMessage = this.getChild('[data-automation-id="adf-password-dialog-error"]');
    copyDialog = this.getChild('[data-automation-id="content-node-selector-title"]');
    copyMenuButton = this.getChild('[id="app.viewer.copy"]');
    deleteMenuButton = this.getChild('[id="app.viewer.delete"]');
    favoriteMenuButton = this.getChild('[id="app.viewer.favorite.add"]');
    removeFavoriteMenuButton = this.getChild('[id="app.viewer.favorite.remove"]');
    shareDialogTitle = this.getChild('[data-automation-id="adf-share-dialog-title"]');
    shareDialogClose = this.getChild('[data-automation-id="adf-share-dialog-close"]');
    constructor(page, rootElement = ViewerOverlayDialogComponent.rootElement) {
        super(page, rootElement);
    }
    async isCopyDialogOpen() {
        await this.copyDialog.waitFor({ state: 'attached', timeout: timeouts.medium });
        return this.copyDialog.isVisible();
    }
    async isCopyDialogClose() {
        await this.copyDialog.waitFor({ state: 'detached', timeout: timeouts.medium });
        return this.copyDialog.isVisible();
    }
    async clickActionsCopy() {
        await this.copyMenuButton.waitFor({ state: 'attached', timeout: timeouts.medium });
        await this.copyMenuButton.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ContentNodeSelectorDialog extends BaseComponent {
    static rootElement = 'adf-content-node-selector';
    constructor(page) {
        super(page, ContentNodeSelectorDialog.rootElement);
    }
    cancelButton = this.getChild('[data-automation-id="content-node-selector-actions-cancel"]');
    actionButton = this.getChild('[data-automation-id="content-node-selector-actions-choose"]');
    locationDropDown = this.getChild('[id="site-dropdown-container"] mat-form-field');
    selectedRow = this.getChild('.adf-is-selected');
    getOptionLocator = (optionName) => this.page.locator('.mat-mdc-select-panel .mdc-list-item__primary-text', { hasText: optionName });
    getRowByName = (name) => this.getChild(`adf-datatable-row`, { hasText: name.toString() });
    getDialogTitle = (text) => this.getChild('[data-automation-id="content-node-selector-title"]', { hasText: text });
    getBreadcrumb = (text) => this.getChild('[data-automation-id="current-folder"]', { hasText: text });
    getFolderIcon = this.getChild('[data-automation-id="dropdown-breadcrumb-trigger"]');
    loadMoreButton = this.getChild('[data-automation-id="adf-infinite-pagination-button"]');
    async loadMoreNodes() {
        await this.spinnerWaitForReload();
        while (await this.loadMoreButton.isVisible()) {
            await this.loadMoreButton.click();
        }
    }
    async selectLocation(location) {
        await this.locationDropDown.click();
        const optionLocator = this.getOptionLocator(location);
        await optionLocator.click();
        await optionLocator.waitFor({ state: 'detached' });
    }
    async selectDestination(folderName) {
        const row = this.getRowByName(folderName);
        await expect(row).toBeVisible();
        await row.click({ trial: true });
        await expect(async () => {
            await row.hover({ timeout: 1000 });
            await row.click();
            await expect(this.selectedRow).toBeVisible();
        }).toPass({
            intervals: [2000, 2000, 2000, 2000, 2000, 2000, 2000],
            timeout: 20000
        });
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class CreateFromTemplateDialogComponent extends BaseComponent {
    static rootElement = 'app-create-from-template-dialog';
    constructor(page) {
        super(page, CreateFromTemplateDialogComponent.rootElement);
    }
    cancelButton = this.getChild('[data-automation-id="create-from-template-dialog-cancel-button"]');
    createButton = this.getChild('[data-automation-id="create-from-template-dialog-create-button"]');
    getDialogTitle = (text) => this.getChild('.mat-dialog-title', { hasText: text });
    getDialogLabel = (text) => this.getChild('label', { hasText: text });
    getErrorByText = (text) => this.page.locator('mat-error', { hasText: text });
    async isErrorMessageDisplayed(errorText) {
        await this.getErrorByText(errorText).waitFor({ state: 'visible', timeout: timeouts.large });
        return this.getErrorByText(errorText).isVisible();
    }
    /**
     * This method is used when we want to fill in Create new folder/document/file from template dialog and choose Create button
     */
    async createFromTemplateAction(nameInput, titleInput, descriptionInput) {
        await this.getDialogLabel('Name *').fill(nameInput);
        if (titleInput) {
            await this.getDialogLabel('Title').fill(titleInput);
        }
        if (descriptionInput) {
            await this.getDialogLabel('Description').fill(descriptionInput);
        }
        await this.createButton.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AdfConfirmDialogComponent extends BaseComponent {
    static rootElement = 'adf-confirm-dialog';
    constructor(page) {
        super(page, AdfConfirmDialogComponent.rootElement);
    }
    getDialogTitle = (text) => this.getChild('[data-automation-id="adf-confirm-dialog-title"]', { hasText: text });
    getDialogContent = (text) => this.getChild('[data-automation-id="adf-confirm-dialog-base-message"]', { hasText: text });
    okButton = this.getChild('[data-automation-id="adf-confirm-dialog-confirmation"]');
    cancelButton = this.getChild('[data-automation-id="adf-confirm-dialog-reject"]');
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class DateTimePicker extends BaseComponent {
    static rootElement = '.mat-calendar';
    calendar = this.getChild('.mat-datepicker-popup');
    dayPicker = this.getChild('mat-month-view');
    nextMonthBtn = this.getChild('.mat-calendar-next-button');
    rootElemLocator = this.page.locator('.mat-datepicker-popup');
    constructor(page) {
        super(page, DateTimePicker.rootElement);
    }
    async isCalendarOpen() {
        const element = this.rootElemLocator;
        return element.isVisible();
    }
    async pickDateTime() {
        const today = new Date();
        const nextAvailableDay = new Date();
        nextAvailableDay.setDate(today.getDate() + 2);
        if (nextAvailableDay.getMonth() !== today.getMonth()) {
            await this.nextMonthBtn.click();
        }
        await this.selectDay(nextAvailableDay.getDate());
    }
    async selectDay(day) {
        const firstActiveDayElem = this.dayPicker.locator(`text=${day}`).first();
        await firstActiveDayElem.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ShareDialogComponent extends BaseComponent {
    static rootElement = 'adf-share-dialog';
    constructor(page) {
        super(page, ShareDialogComponent.rootElement);
    }
    closeButton = this.getChild('[data-automation-id="adf-share-dialog-close"]');
    dialogTitle = this.getChild('[data-automation-id="adf-share-dialog-title"]');
    infoText = this.getChild('.adf-share-link__info').first();
    labels = '.adf-share-link__label';
    shareToggle = this.getChild(`[data-automation-id='adf-share-toggle']`);
    url = this.getChild(`[data-automation-id='adf-share-link']`);
    urlAction = this.getChild('.adf-input-action');
    expireToggle = this.getChild(`[data-automation-id='adf-expire-toggle']`);
    expireInput = this.getChild('input[formcontrolname="time"]');
    datetimePickerButton = this.getChild('.mat-datepicker-toggle');
    dateTimePicker = new DateTimePicker(this.page);
    getDialogLabel = () => this.getChild('label').innerText();
    getErrorByText = (text) => this.page.locator('mat-error', { hasText: text });
    async getLabels() {
        return this.page.$$eval('.adf-share-link__label', (elements) => elements.map((element) => element.textContent));
    }
    async getDialogTitle() {
        return this.dialogTitle.innerText();
    }
    async getInfoText() {
        return this.infoText.innerText();
    }
    async getLinkUrl() {
        return this.url.first().inputValue();
    }
    async isUrlReadOnly() {
        const urlAttr = await this.url.getAttribute('readonly');
        return urlAttr === 'true';
    }
    async isCloseEnabled() {
        return this.closeButton.isEnabled();
    }
    async clickClose() {
        await this.page.waitForTimeout(timeouts.tiny);
        await this.closeButton.click();
    }
    async isToggleStatus(toggle, status) {
        const toggleClass = await toggle.getAttribute('class');
        return toggleClass.includes(status);
    }
    async isShareToggleChecked() {
        const shareToggleElement = await this.shareToggle.elementHandle();
        return this.isToggleStatus(shareToggleElement, 'checked');
    }
    async isExpireToggleEnabled() {
        const expireToggleElement = await this.expireToggle.elementHandle();
        return this.isToggleStatus(expireToggleElement, 'checked');
    }
    async getExpireDate() {
        return this.expireInput.inputValue();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class UploadNewVersionDialog extends BaseComponent {
    static rootElement = 'adf-new-version-uploader-dialog';
    cancelButton = this.getChild('#adf-new-version-cancel');
    uploadButton = this.getChild('[data-automation-id="adf-new-version-file-upload"]');
    majorOption = this.getChild('#adf-new-version-major');
    minorOption = this.getChild('#adf-new-version-minor');
    description = this.getChild('#adf-new-version-text-area');
    title = this.getChild(' [data-automation-id="new-version-uploader-dialog-title"]');
    constructor(page) {
        super(page, UploadNewVersionDialog.rootElement);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ManageVersionsDialog extends BaseComponent {
    static rootElement = '.adf-new-version-uploader-dialog';
    async viewFileVersion(version) {
        const versionActionsButton = this.page.locator(`[id="adf-version-list-action-menu-button-${version}"]`);
        await versionActionsButton.click();
    }
    constructor(page) {
        super(page, ManageVersionsDialog.rootElement);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class UploadDialog extends BaseComponent {
    static rootElement = '.adf-upload-dialog';
    uploadDialog = this.page.locator('.adf-upload-dialog');
    closeButton = this.getChild('#adf-upload-dialog-close');
    minimizeButton = this.page.locator('[data-automation-id="adf-upload-dialog__toggle-minimize"]');
    uploadDialogMinimized = this.page.locator('.adf-upload-dialog--minimized');
    constructor(page) {
        super(page, UploadDialog.rootElement);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AdfDeleteTrashComponent extends BaseComponent {
    static rootElement = 'adf-confirm-dialog';
    constructor(page) {
        super(page, AdfDeleteTrashComponent.rootElement);
    }
    dialogTitle = this.getChild('[data-automation-id="adf-confirm-dialog-title"]');
    dialogDescription = this.getChild('[data-automation-id="adf-confirm-dialog-base-message"]');
    deleteButton = this.getChild('[id="adf-confirm-accept"]');
    keepButton = this.getChild('[id="adf-confirm-cancel"]');
    async waitForDialog() {
        await this.dialogTitle.waitFor();
    }
    async isDialogOpen() {
        return this.dialogTitle.isVisible();
    }
    async getDialogTitle() {
        return this.dialogTitle.textContent();
    }
    async getDialogDescription() {
        return this.dialogDescription.textContent();
    }
    async isDeleteEnabled() {
        return this.deleteButton.isEnabled();
    }
    async isKeepEnabled() {
        return this.keepButton.isEnabled();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class LinkRulesDialog extends BaseComponent {
    static rootElement = 'aca-rule-set-picker';
    constructor(page) {
        super(page, LinkRulesDialog.rootElement);
    }
    cancelButton = this.getChild('[data-automation-id="content-node-selector-actions-cancel"]');
    selectFolderButton = this.getChild('button', { hasText: ' Select folder ' });
    emptyLinkRules = this.getChild('.adf-empty-content__title');
    getOptionLocator = (optionName) => this.page.locator('.mat-mdc-select-panel .mdc-list-item__primary-text', { hasText: optionName });
    getRowByName = (name) => this.getChild(`adf-datatable-row`, { hasText: name.toString() });
    getDialogTitle = (text) => this.getChild('[data-automation-id="content-node-selector-title"]', { hasText: text });
    getBreadcrumb = (text) => this.getChild('[data-automation-id="current-folder"]', { hasText: text });
    getFolderIcon = this.getChild('.adf-dropdown-breadcrumb-icon', { hasText: 'folder' });
    getLibraryIcon = this.getChild('.adf-empty-content__icon', { hasText: 'library_books' });
    async selectDestination(folderName) {
        const row = this.getRowByName(folderName);
        await expect(row).toBeVisible();
        await row.click({ trial: true });
        await expect(async () => {
            await row.hover({ timeout: 1000 });
            await row.click();
            await expect(this.selectFolderButton).toBeEnabled();
        }).toPass({
            intervals: [2000, 2000, 2000, 2000, 2000, 2000, 2000],
            timeout: 20000
        });
    }
    async waitForLinkRules() {
        await this.getLibraryIcon.waitFor();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class EditDialog extends BaseComponent {
    static rootElement = 'mat-dialog-container';
    editDialog = this.getChild('');
    titleInput = this.getChild('[data-automation-id="adf-folder-dialog-title"]');
    cancelButton = this.getChild('#adf-folder-cancel-button');
    updateButton = this.getChild('#adf-folder-create-button');
    descriptionInput = this.getChild('#adf-folder-description-input');
    nameInput = this.getChild('#adf-folder-name-input');
    fieldHint = this.getChild('mat-hint');
    constructor(page) {
        super(page, EditDialog.rootElement);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ManageRulesDialogComponent extends BaseComponent {
    static rootElement = 'aca-edit-rule-dialog';
    createRuleButton = this.getChild('[data-automation-id="edit-rule-dialog-submit"]');
    cancelRuleButton = this.getChild('.aca-edit-rule-dialog__footer button').filter({ hasText: 'Cancel' });
    ruleNameInputLocator = this.getChild('[id="rule-details-name-input"]');
    ruleDescriptionInputLocator = this.getChild('[id="rule-details-description-textarea"]');
    addConditionButton = this.getChild('[data-automation-id="add-condition-button"]');
    addConditionGroupButton = this.getChild('[data-automation-id="add-group-button"]');
    fieldDropDown = this.getChild('[data-automation-id="field-select"]');
    comparatorDropDown = this.getChild('[data-automation-id="comparator-select"]');
    valueField = this.getChild('[data-automation-id="value-input"]');
    whenCreatedCheckbox = this.getChild('[data-automation-id="rule-trigger-checkbox-inbound"]');
    whenUpdatedCheckbox = this.getChild('[data-automation-id="rule-trigger-checkbox-update"]');
    whenDeletedCheckbox = this.getChild('[data-automation-id="rule-trigger-checkbox-outbound"]');
    destinationFolderButton = this.getChild('[data-automation-id="card-textitem-clickable-icon-destination-folder"]');
    ruleInBackgroundCheckbox = this.getChild('[data-automation-id="rule-option-checkbox-asynchronous"]');
    ruleSubfoldersCheckbox = this.getChild('[data-automation-id="rule-option-checkbox-inheritable"]');
    ruleDisableCheckbox = this.getChild('[data-automation-id="rule-option-checkbox-disabled"] input');
    actionsEllipsisButtons = this.getChild('[data-automation-id="rule-action-list-action-menu"]');
    actionsEllipsisDelete = this.page.locator('[data-automation-id="rule-action-list-remove-action-button"]');
    conditionsEllipsisButtons = this.getChild('[data-automation-id="condition-actions-button"]');
    conditionsEllipsisDelete = this.page.locator('button[title="Remove"]');
    constructor(page) {
        super(page, ManageRulesDialogComponent.rootElement);
    }
    async deleteActions(noActions) {
        for (let i = 0; i < noActions; i++) {
            await this.actionsEllipsisButtons.first().click();
            await this.actionsEllipsisDelete.click();
        }
    }
    async deleteConditions(noConditions) {
        for (let i = 0; i < noConditions; i++) {
            await this.conditionsEllipsisButtons.first().click();
            await this.conditionsEllipsisDelete.click();
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ManageRules extends BaseComponent {
    static rootElement = '.aca-manage-rules';
    getGroupsList = (optionName) => this.getChild('.aca-rule-list-item__header', { hasText: optionName });
    ruleToggle = this.getChild('.aca-manage-rules__container .mdc-switch').first();
    ruleToggleFalse = this.getChild('aca-rule-list-grouping aca-rule-list-item .mdc-switch--unselected').first();
    ruleDetailsTitle = this.getChild('.aca-manage-rules__container__rule-details__header__title__name');
    ruleDetailsDeleteButton = this.getChild('#delete-rule-btn');
    ruleDetailsEditButton = this.getChild('#edit-rule-btn');
    ruleDetailsWhenText = this.getChild('[data-automation-id="rule-details-triggers-component"]');
    ruleDetailsPerformActionsDiv = this.getChild('adf-card-view-textitem mat-form-field input');
    rulesEmptyListTitle = this.getChild('.adf-empty-content__title');
    ruleActions = this.getChild('aca-rule-action');
    ruleConditionsInGroup = this.getChild('aca-rule-composite-condition aca-rule-simple-condition');
    ruleDescription = this.getChild('.aca-manage-rules__container__rule-details__header__title__description');
    constructor(page) {
        super(page, ManageRules.rootElement);
    }
    async checkAspects(aspects) {
        for (let i = 0; i < aspects.length; i++) {
            const aspectsActions = await this.ruleDetailsPerformActionsDiv.nth(i).inputValue();
            expect(aspects).toContain(aspectsActions);
        }
    }
    async checkIfRuleListEmpty() {
        return this.rulesEmptyListTitle.isVisible();
    }
    async checkIfRuleIsOnTheList(ruleName) {
        await expect(this.getGroupsList(ruleName)).toBeVisible({ timeout: 5000 });
    }
    async countConditionsInGroup() {
        return this.ruleConditionsInGroup.count();
    }
    async turnOffRuleToggle() {
        await expect(async () => {
            await this.ruleToggle.hover({ timeout: 1000 });
            await this.ruleToggle.click();
            await expect(this.ruleToggleFalse).toBeVisible();
        }).toPass({
            intervals: [2000, 2000, 2000, 2000, 2000, 2000, 2000],
            timeout: 20000
        });
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SpinnerComponent extends BaseComponent {
    static rootElement = 'mat-progress-spinner';
    constructor(page, rootElement = SpinnerComponent.rootElement) {
        super(page, rootElement);
    }
    async waitForReload() {
        try {
            await this.getChild('').waitFor({ state: 'attached', timeout: 2000 });
            await this.getChild('').waitFor({ state: 'detached', timeout: 2000 });
        }
        catch (e) {
            this.logger.info('Spinner was not present');
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
var ActionType;
(function (ActionType) {
    ActionType["AddAspect"] = "Add aspect";
    ActionType["SimpleWorkflow"] = "Add simple workflow";
    ActionType["IncrementCounter"] = "Increment Counter";
    ActionType["CheckIn"] = "Check in";
    ActionType["AutoDeclareOptions"] = "Auto-Declare Options";
    ActionType["CheckOut"] = "Check out";
    ActionType["Copy"] = "Copy";
    ActionType["ExecuteScript"] = "Execute script";
    ActionType["ExtractCommonMetadataFields"] = "Extract common metadata fields";
    ActionType["FileAsRecord"] = "File as Record";
    ActionType["FileVersionAsRecord"] = "File Version as Record";
    ActionType["HideRecord"] = "Hide Record";
    ActionType["Import"] = "Import";
    ActionType["Move"] = "Move";
    ActionType["RemoveAspect"] = "Remove aspect";
    ActionType["RequestAIRenditions"] = "Request AI renditions";
    ActionType["SendEmail"] = "Send email";
    ActionType["SetPropertyValue"] = "Set property value";
    ActionType["SpecialiseType"] = "Specialise type";
    ActionType["TransformAndCopyContent"] = "Transform and copy content";
    ActionType["TransformAndCopyImage"] = "Transform and copy image";
})(ActionType || (ActionType = {}));
class ActionsDropdownComponent extends BaseComponent {
    static rootElement = 'aca-edit-rule-dialog aca-rule-action-list';
    getOptionLocator = (optionName) => this.page.locator('.mat-mdc-select-panel .mdc-list-item__primary-text', { hasText: optionName }).first();
    ruleActionLocator = this.getChild('aca-rule-action');
    addActionButtonLocator = this.getChild('[data-automation-id="rule-action-list-add-action-button"]');
    actionDropdownLocator = this.getChild('[data-automation-id="rule-action-select"]');
    actionAspectNameLocator = '[data-automation-id="header-aspect-name"] .adf-property-field';
    actionCheckInInputLocator = '[data-automation-id="header-description"] input';
    actionAutoDeclareLocator = '[data-automation-id="header-version"] mat-select';
    actionSimpleWorkflowStepInputLocator = '[data-automation-id="header-approve-step"] input';
    actionSimpleWorkflowApproveFolderLocator = `[data-automation-id="header-approve-folder"] mat-icon`;
    actionSimpleWorkflowActionChoiceLocator = '[data-automation-id="content-node-selector-actions-choose"]';
    actionSimpleWorkflowLabelApproveLocator = `[data-automation-id="card-boolean-label-approve-move"]`;
    actionSimpleWorkflowSRejectStepLocator = '[data-automation-id="header-reject-step"] input';
    actionSimpleWorkflowRejectFolderLocator = `[data-automation-id="header-reject-folder"] input`;
    constructor(page) {
        super(page, ActionsDropdownComponent.rootElement);
    }
    async selectAction(action, index) {
        if (index > 0) {
            await this.addActionButtonLocator.click();
        }
        await this.actionDropdownLocator.nth(index).hover({ timeout: 1000 });
        await this.actionDropdownLocator.nth(index).click();
        const option = this.getOptionLocator(action);
        await option.click();
    }
    async dropdownSelection(selectValue, locator, index) {
        await this.ruleActionLocator.nth(index).locator(locator).click();
        await this.getOptionLocator(selectValue).nth(0).click();
    }
    async insertCheckInActionValues(checkInValue, index) {
        await this.ruleActionLocator.nth(index).locator(this.actionCheckInInputLocator).fill(checkInValue);
    }
    async insertAddAspectActionValues(AspectValue, index) {
        await this.dropdownSelection(AspectValue, this.actionAspectNameLocator, index);
    }
    async insertAutoDeclareOptionsActionValues(autoDeclareOptionsValue, index) {
        await this.dropdownSelection(autoDeclareOptionsValue, this.actionAutoDeclareLocator, index);
    }
    async insertSimpleWorkflowActionValues(stepValue, index) {
        await this.ruleActionLocator.nth(index).locator(this.actionSimpleWorkflowStepInputLocator).fill(stepValue);
        await this.ruleActionLocator.nth(index).locator(this.actionSimpleWorkflowApproveFolderLocator).click();
        await this.page.locator(this.actionSimpleWorkflowActionChoiceLocator).click();
        await this.ruleActionLocator.nth(index).locator(this.actionSimpleWorkflowLabelApproveLocator).click();
        await this.ruleActionLocator.nth(index).locator(this.actionSimpleWorkflowSRejectStepLocator).fill(stepValue);
        await this.ruleActionLocator.nth(index).locator(this.actionSimpleWorkflowRejectFolderLocator).click();
        await this.page.locator(this.actionSimpleWorkflowActionChoiceLocator).click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
var Field;
(function (Field) {
    Field["Name"] = "Name";
    Field["Size"] = "Size";
    Field["Mimetype"] = "Mimetype";
    Field["Encoding"] = "Encoding";
    Field["HasCategory"] = "Has category";
    Field["HasTag"] = "Has tag";
    Field["HasAspect"] = "Has aspect";
})(Field || (Field = {}));
var Comparator;
(function (Comparator) {
    Comparator["Equals"] = "(=) Equals";
    Comparator["Contains"] = "Contains";
    Comparator["StartsWith"] = "Starts with";
    Comparator["EndsWith"] = "Ends with";
})(Comparator || (Comparator = {}));
class ConditionComponent extends ManageRulesDialogComponent {
    getOptionLocator = (optionName) => this.page.locator(`.cdk-overlay-pane .mat-mdc-option span`, { hasText: optionName });
    async selectField(fields, index) {
        await this.fieldDropDown.nth(index).click();
        const option = this.getOptionLocator(fields);
        await option.click();
    }
    async selectComparator(comparators, index) {
        await this.comparatorDropDown.nth(index).click();
        const option = this.getOptionLocator(comparators);
        await option.click();
    }
    async addCondition(fields, value, index, comparators) {
        await this.addConditionButton.first().click();
        await this.selectField(fields, index);
        if (comparators) {
            await this.selectComparator(comparators, index);
        }
        await this.valueField.nth(index).fill(value);
    }
    async addConditionGroup(fields, value, index, comparators) {
        await this.addConditionGroupButton.last().click();
        await this.addConditionButton.nth(index).click();
        await this.selectField(fields, index);
        if (comparators) {
            await this.selectComparator(comparators, index);
        }
        await this.valueField.nth(index).fill(value);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AdfInfoDrawerComponent extends BaseComponent {
    static rootElement = 'adf-info-drawer';
    constructor(page) {
        super(page, AdfInfoDrawerComponent.rootElement);
    }
    categoriesManagement = this.getChild('adf-categories-management');
    tagsCreator = this.getChild('adf-tags-creator');
    getNameField = (labelText) => this.getChild(`[data-automation-id="library-name-properties-wrapper"] input[placeholder='${labelText}']`);
    getIdField = (labelText) => this.getChild(`[data-automation-id="library-id-properties-wrapper"] input[placeholder='${labelText}']`);
    getVisibilityField = (labelText) => this.getChild(`[data-automation-id="library-visibility-properties-wrapper"] mat-select[ng-reflect-placeholder='${labelText}']`);
    getDescriptionField = this.getChild('[data-automation-id="library-description-properties-wrapper"] textarea');
    propertiesTab = this.page.getByRole('tab', { name: 'Properties' });
    commentsTab = this.page.getByRole('tab', { name: 'Comments' });
    infoDrawerTabs = this.getChild('.adf-info-drawer-tab');
    commentInputField = this.page.locator('#comment-input');
    commentsHeader = this.getChild('#comment-header');
    addCommentButton = this.getChild('[data-automation-id="comments-input-add"]');
    commentsList = this.getChild('.adf-comment-list-item');
    commentUsername = this.getChild('.adf-comment-user-name');
    commentTextContent = this.getChild('.adf-comment-message');
    commentTimestamp = this.getChild('.adf-comment-message-time');
    infoDrawerPanel = this.page.locator('.adf-info-drawer');
    headerTitle = this.page.locator('.adf-info-drawer-layout-header-title').getByRole('heading');
    editButton = this.page.getByRole('button', { name: 'Edit' });
    cancelButton = this.page.getByRole('button', { name: 'Cancel' });
    updateButton = this.page.getByRole('button', { name: 'Update' });
    hintMessage = this.page.locator('mat-hint');
    errorMessage = this.page.locator('mat-error');
    expandDetailsButton = this.getChild(`button[title='Expand panel']`);
    expandedDetailsTabs = this.page.locator('.aca-details-container .mdc-tab__text-label');
    expandedDetailsPermissionsTab = this.expandedDetailsTabs.getByText('Permissions');
    nameField = this.page.locator('input[placeholder=Name]');
    idField = this.page.locator(`input[placeholder='Library ID']`);
    descriptionField = this.page.locator('textarea[placeholder=Description]');
    visibilityField = this.infoDrawerPanel.getByRole('combobox');
    selectVisibility = (visibilityOption) => this.page.getByRole('listbox').getByRole('option', { name: visibilityOption }).click();
    tagsAccordion = this.getChild('[data-automation-id="adf-content-metadata-tags-panel"]');
    categoriesAccordion = this.getChild('[data-automation-id="adf-content-metadata-categories-panel"]');
    tagsAccordionPenButton = this.tagsAccordion.locator('[data-automation-id="showing-tag-input-button"]');
    categoriesAccordionPenButton = this.categoriesAccordion.locator('[data-automation-id="meta-data-categories-edit"]');
    tagsInput = this.tagsCreator.locator('input');
    createTagButton = this.tagsCreator.locator('[role="button"]');
    tagsChips = this.tagsCreator.locator('mat-chip');
    tagsChipsXButton = this.tagsChips.locator('button');
    tagsAccordionCancelButton = this.getChild('[data-automation-id="reset-tags-metadata"]');
    tagsAccordionConfirmButton = this.getChild('[data-automation-id="save-tags-metadata"]');
    categoriesAccordionCancelButton = this.getChild('[data-automation-id="reset-metadata"]');
    categoriesAccordionConfirmButton = this.getChild('[data-automation-id="save-categories-metadata"]');
    categoriesInput = this.categoriesManagement.locator('input');
    categoriesListItems = this.categoriesManagement.locator('mat-list-item');
    categoriesItemRemoveButton = this.categoriesManagement.locator('[data-automation-id="categories-remove-category-button"]');
    categoriesCreatedList = this.getChild('.adf-metadata-categories');
    async checkCommentsHeaderCount() {
        const commentsCountTextContent = await this.commentsHeader.textContent();
        const commentsCountString = commentsCountTextContent.match(/\d+/g)[0];
        return parseInt(commentsCountString, 10);
    }
    async verifyCommentsCountFromList(expectedNumber) {
        const commentsCountFromList = await this.commentsList.count();
        expect(commentsCountFromList).toEqual(expectedNumber);
    }
    async waitForComments() {
        await this.commentsList.first().waitFor();
    }
    async addCommentToNode(commentText) {
        await this.commentInputField.fill(commentText);
        await this.addCommentButton.click();
    }
    async getHeaderTitle() {
        return this.headerTitle.textContent();
    }
    async getTabsCount() {
        return this.infoDrawerTabs.count();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class AcaHeader extends BaseComponent {
    static rootElement = 'aca-toolbar';
    moreActionsButton = this.getChild('button[id="app.viewer.toolbar.more"]');
    toolbarMoreActions = this.getChild('button[id="app.toolbar.more"]');
    createButton = this.getChild('[id="app.toolbar.create"]');
    viewDetails = this.getChild('[title="View Details"]');
    viewButton = this.getChild('button[title="View"]');
    searchButton = this.getChild('button[id="app.toolbar.search"]');
    fullScreenButton = this.getChild('button[id="app.viewer.fullscreen"]');
    shareButton = this.getChild('button[id="share-action-button"]');
    downloadButtonViewer = this.getChild('button[id="app.viewer.download"]');
    downloadButton = this.getChild('button[id="app.toolbar.download"]');
    sharedDownloadButton = this.getChild('button[id="app.viewer.shared.download"]');
    uploadButton = this.getChild('button[id="app.toolbar.upload"]');
    uploadFileButton = this.page.locator('button[id="app.create.uploadFile"]');
    uploadInput = this.page.locator('input[id="app-upload-files"]');
    uploadNewVersionButton = this.page.locator('#app-upload-file-version');
    permanentlyDeleteButton = this.getChild('button[id="app.toolbar.purgeDeletedNodes"]');
    restoreButton = this.getChild('button[id="app.toolbar.restoreDeletedNodes"]');
    constructor(page) {
        super(page, AcaHeader.rootElement);
    }
    matMenu = new MatMenuComponent(this.page);
    async clickViewerMoreActions() {
        await this.moreActionsButton.waitFor({ state: 'attached' });
        await this.moreActionsButton.click();
    }
    async clickMoreActions() {
        await this.toolbarMoreActions.waitFor({ state: 'attached' });
        await this.toolbarMoreActions.click();
    }
    async clickCreateFolderFromTemplate() {
        await this.createButton.click();
        await this.matMenu.createFolderFromTemplate.click();
    }
    async verifyToolbarPrimaryActions(expectedToolbarPrimary) {
        const buttons = await this.page.$$('aca-toolbar button');
        const actualPrimaryActions = await Promise.all(buttons.map(async (button) => {
            const title = await button.getAttribute('title');
            return title || '';
        }));
        for (const action of expectedToolbarPrimary) {
            expect(actualPrimaryActions.includes(action), `Expected to contain ${action}`).toBe(true);
        }
    }
    async clickCreateFileFromTemplate() {
        await this.createButton.click();
        await this.matMenu.createFileFromTemplate.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ViewerComponent extends BaseComponent {
    static rootElement = 'adf-viewer';
    viewerLocator = this.getChild('.adf-viewer-render-layout-content');
    closeButtonLocator = this.getChild('.adf-viewer-close-button');
    fileTitleButtonLocator = this.getChild('.adf-viewer__file-title');
    pdfViewerContentPages = this.getChild('.adf-pdf-viewer__content .page');
    shareButton = this.getChild('button[id="share-action-button"]');
    downloadButton = this.getChild('button[id="app.viewer.download"]');
    allButtons = this.getChild('button');
    unknownFormat = this.getChild(`adf-viewer-unknown-format .adf-viewer__unknown-format-view`);
    viewerImage = this.viewerLocator.locator('.cropper-canvas img');
    viewerDocument = this.viewerLocator.locator('.adf-pdf-viewer__content [role="document"]');
    documentThumbnailButton = this.getChild('[data-automation-id="adf-thumbnails-button"]');
    thumbnailsPages = this.getChild('[data-automation-id="adf-thumbnails-content"] adf-pdf-thumb');
    thumbnailsCloseButton = this.getChild('[data-automation-id="adf-thumbnails-close"]');
    viewerPage = this.getChild('[data-automation-id="adf-page-selector"]');
    viewerMedia = this.getChild('adf-media-player');
    viewerSpinner = this.getChild('.adf-viewer-render__loading-screen');
    toolbar = new AcaHeader(this.page);
    constructor(page) {
        super(page, ViewerComponent.rootElement);
    }
    async isPdfViewerContentDisplayed() {
        const count = await this.pdfViewerContentPages.count();
        return count > 0;
    }
    async waitForViewerToOpen(waitForViewerContent) {
        await this.viewerLocator.waitFor({ state: 'visible', timeout: timeouts.medium });
        if (waitForViewerContent) {
            await this.spinnerWaitForReload();
        }
    }
    async isViewerOpened() {
        await this.waitForViewerToOpen();
        return this.viewerLocator.isVisible();
    }
    async waitForViewerLoaderToFinish() {
        await this.viewerSpinner.waitFor({ state: 'hidden', timeout: timeouts.extraLarge });
    }
    async checkViewerActivePage(pageNumber) {
        await expect(this.viewerPage).toHaveValue(pageNumber.toString());
    }
    async clickViewerThumbnailPage(pageNumber) {
        await this.thumbnailsPages.nth(pageNumber - 1).click();
    }
    async isCloseButtonDisplayed() {
        await this.closeButtonLocator.waitFor({ state: 'visible', timeout: timeouts.normal });
        return this.closeButtonLocator.isEnabled({ timeout: timeouts.normal });
    }
    async isFileTitleDisplayed() {
        await this.fileTitleButtonLocator.waitFor({ state: 'visible', timeout: timeouts.normal });
        return this.fileTitleButtonLocator.isVisible();
    }
    async getFileTitle() {
        await this.fileTitleButtonLocator.waitFor({ state: 'visible', timeout: timeouts.normal });
        return this.fileTitleButtonLocator.textContent();
    }
    async getCloseButtonTooltip() {
        await this.closeButtonLocator.waitFor({ state: 'visible', timeout: timeouts.normal });
        return this.closeButtonLocator.getAttribute('title');
    }
    async verifyViewerPrimaryActions(expectedToolbarPrimary) {
        const toRemove = ['Close', 'Previous File', 'Next File', 'View details'];
        const removeClosePreviousNextOldInfo = (actions) => actions.filter((elem) => !toRemove.includes(elem));
        const buttons = await this.page.$$('adf-viewer button');
        let actualPrimaryActions = await Promise.all(buttons.map(async (button) => {
            const title = await button.getAttribute('title');
            return title || '';
        }));
        actualPrimaryActions = removeClosePreviousNextOldInfo(actualPrimaryActions);
        for (const action of expectedToolbarPrimary) {
            expect(actualPrimaryActions.includes(action), `Expected to contain ${action}`).toBe(true);
        }
    }
    async checkUnknownFormatIsDisplayed() {
        await this.unknownFormat.waitFor({ state: 'visible', timeout: timeouts.normal });
    }
    async getUnknownFormatMessage() {
        return this.unknownFormat.locator(`.adf-viewer__unknown-label`).innerText();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchInputComponent extends BaseComponent {
    static rootElement = 'aca-page-layout';
    searchInput = this.page.locator('#app-control-input');
    searchButton = this.page.locator('.aca-search-input--search-button');
    searchCloseButton = this.page.locator('.aca-search-input--close-button');
    /**
     * Method used in cases where user have possibility to navigate "inside" the element (it's clickable and has link attribute).
     * Perform action .click() to navigate inside it
     *
     * @returns reference to cell element which contains link.
     */
    getCellLinkByName = (name) => this.getChild('.adf-datatable-row[role="row"]', { hasText: name });
    constructor(page, rootElement = SearchInputComponent.rootElement) {
        super(page, rootElement);
    }
    async performDoubleClickFolderOrFileToOpen(name) {
        await this.getCellLinkByName(name).waitFor({ state: 'visible', timeout: timeouts.medium });
        await this.getCellLinkByName(name).dblclick();
        await this.spinnerWaitForReload();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchOverlayComponent extends BaseComponent {
    static rootElement = '.cdk-overlay-pane';
    searchFilesOption = this.getChild('input#content-input');
    searchFoldersOption = this.getChild('input#folder-input');
    searchLibrariesOption = this.getChild('input#libraries-input');
    searchInput = this.page.locator('#app-control-input');
    searchButton = this.page.locator('app-search-input-control button[title="Search"]');
    searchInputControl = this.page.locator('.app-search-control');
    searchOptions = this.page.locator('.app-search-options');
    constructor(page, rootElement = SearchOverlayComponent.rootElement) {
        super(page, rootElement);
    }
    async isFoldersOptionChecked() {
        const optClass = await this.searchFoldersOption.getAttribute('class');
        return optClass.includes('.mat-mdc-checkbox-checked');
    }
    async isFilesOptionChecked() {
        const optClass = await this.searchFilesOption.getAttribute('class');
        return optClass.includes('.mat-mdc-checkbox-checked');
    }
    async isLibrariesOptionChecked() {
        const optClass = await this.searchLibrariesOption.getAttribute('class');
        return optClass.includes('.mat-mdc-checkbox-checked');
    }
    async clearOptions() {
        if (await this.isFilesOptionChecked()) {
            await this.searchFilesOption.click();
        }
        if (await this.isFoldersOptionChecked()) {
            await this.searchFoldersOption.click();
        }
        if (await this.isLibrariesOptionChecked()) {
            await this.searchLibrariesOption.click();
        }
    }
    async checkOnlyFolders() {
        await this.clearOptions();
        await this.searchFoldersOption.click();
    }
    async checkOnlyFiles() {
        await this.clearOptions();
        await this.searchFilesOption.click();
    }
    async checkLibraries() {
        await this.clearOptions();
        await this.searchLibrariesOption.click();
    }
    async checkFilesAndFolders() {
        await this.clearOptions();
        await this.searchFilesOption.click();
        await this.searchFoldersOption.click();
    }
    async searchFor(input) {
        await this.searchInput.fill(input);
        await this.searchButton.click({ force: true });
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchSortingPicker extends BaseComponent {
    static rootElement = '#aca-button-action-menu';
    actionMenu = this.page.locator('[data-automation-id="auto_header_content_id_$thumbnail"]');
    sortOrderButton = this.page.locator('#aca-button-sorting-menu');
    sortByDropdownExpanded = this.page.locator('.mat-mdc-menu-panel').first();
    sortByList = this.page.locator('.mat-mdc-menu-panel button');
    constructor(page, rootElement = SearchSortingPicker.rootElement) {
        super(page, rootElement);
    }
    async waitForSortByDropdownToExpand() {
        await this.sortByDropdownExpanded.waitFor();
    }
    async isSortOrderButtonDisplayed() {
        return this.sortOrderButton.isVisible();
    }
    async isSortByDropdownExpanded() {
        return this.sortByDropdownExpanded.isVisible();
    }
    async clickSortByDropdown() {
        await this.sortOrderButton.click();
        await this.waitForSortByDropdownToExpand();
    }
    async getSortByOptionsList() {
        const sortOptionsCount = await this.sortByList.count();
        const sortByOptions = [];
        for (let i = 1; i < sortOptionsCount; i++) {
            const textContent = (await this.sortByList.nth(i).textContent()).trim();
            sortByOptions.push(textContent);
        }
        sortByOptions.sort((a, b) => a.localeCompare(b));
        return sortByOptions;
    }
    async sortBy(option, direction) {
        await this.actionMenu.click();
        await this.clickSortByDropdown();
        if (!(await this.isSortByDropdownExpanded())) {
            await this.clickSortByDropdown();
        }
        const elem = this.sortByList.getByText(option);
        const optionId = await elem.locator('..').getAttribute('id');
        await elem.click();
        const directionSortElement = this.page.locator(`[id="${optionId}-${direction.toLocaleLowerCase()}"]`);
        await directionSortElement.click();
        await this.progressBarWaitForReload();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFilters extends BaseComponent {
    static rootElement = '.aca-content__advanced-filters';
    constructor(page) {
        super(page, SearchFilters.rootElement);
    }
    filtersButtons = this.page.locator('adf-search-widget-chip');
    logicFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Logic' });
    propertiesFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Properties' });
    dateFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Date' });
    locationFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Location' });
    tagsFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Tags' });
    categoriesFilter = this.page.locator('adf-search-widget-chip', { hasText: 'Categories' });
    resetButton = this.page.locator('button', { hasText: 'Reset' });
    menuCardTitle = this.page.locator('.adf-search-filter-title');
    menuCardClose = this.page.locator('.adf-search-filter-title-action');
    menuCardClear = this.page.locator('#cancel-filter-button');
    menuCardApply = this.page.locator('#apply-filter-button');
    dropdownOptions = this.page.locator(`mat-option`);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersCategories extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersCategories.rootElement);
    }
    addOptionInput = this.getChild(`[data-automation-id$='adf-search-chip-autocomplete-input']`);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersDate extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersDate.rootElement);
    }
    createdTab = this.getChild(`[role='tab']`, { hasText: 'Created' });
    modifiedTab = this.getChild(`[role='tab']`, { hasText: 'Modified' });
    createdTabTitle = this.createdTab.locator(`div`);
    modifiedTabTitle = this.modifiedTab.locator(`div`);
    anytimeButton = this.getChild(`[data-automation-id$='date-range-anytime']`);
    anytimeRadioButton = this.anytimeButton.locator(`input`);
    inTheLastButton = this.getChild(`[data-automation-id$='date-range-in-last']`);
    inTheLastInput = this.getChild(`[data-automation-id$='date-range-in-last-input']`);
    inTheLastDropdown = this.getChild(`[data-automation-id$='date-range-in-last-dropdown']`);
    betweenButton = this.getChild(`[data-automation-id$='date-range-between']`);
    betweenRadioButton = this.betweenButton.locator(`input`);
    betweenStartDate = this.getChild(`[data-automation-id$='date-range-between-start-input']`);
    betweenEndDate = this.getChild(`[data-automation-id$='date-range-between-end-input']`);
    async openCreatedModifiedTab(page, tab) {
        switch (tab) {
            case 'Created':
                await page.searchFiltersDate.createdTab.click();
                break;
            case 'Modified':
                await page.searchFiltersDate.modifiedTab.click();
                break;
            default:
                break;
        }
        await page.page.waitForTimeout(2000);
    }
    /**
     * Method used in cases where we want to filter search results by Date
     *
     * @param searchPage page context for the test
     * @param filterType filter type for the Date filter
     * @param dateFilterTab tab in Date filter. Either Created or Modified
     * @param searchPhrase search phrase for the search
     * @param searchType type of items we want in search results e.g. files or folders
     * @param expectSearchResults expect a number of search results
     * @param inTheLastInputValue a value for 'in the last' input. e.g. in the last X days
     * @param startDay start day for time-frame search. DD-MMMM-YY
     * @param endDay end day for time-frame search. DD-MMMM-YY
     */
    async filterFilesByDate(params) {
        const { searchPage, filterType, dateFilterTab, searchPhrase, searchType, expectSearchResults, inTheLastInputValue, startDay, endDay } = params;
        await searchPage.searchWithin(searchPhrase, searchType);
        await searchPage.searchFilters.dateFilter.click();
        if (dateFilterTab === 'Modified') {
            await searchPage.searchFiltersDate.openCreatedModifiedTab(searchPage, 'Modified');
        }
        switch (filterType) {
            case 'anytime':
                await searchPage.searchFiltersDate.anytimeButton.click();
                break;
            case 'inTheLast':
                await searchPage.searchFiltersDate.inTheLastButton.click();
                await searchPage.searchFiltersDate.inTheLastInput.fill(inTheLastInputValue);
                break;
            case 'between':
                await searchPage.searchFiltersDate.betweenButton.click();
                await searchPage.searchFiltersDate.betweenStartDate.fill(startDay);
                await searchPage.searchFiltersDate.betweenEndDate.fill(endDay);
                break;
            default:
                throw new Error('Invalid filter type');
        }
        await searchPage.searchFilters.menuCardApply.click();
        await searchPage.dataTable.spinnerWaitForReload();
        expect(await searchPage.dataTable.getRowsCount()).toEqual(expectSearchResults);
        let dateText;
        if (filterType === 'between') {
            if (dateFilterTab === 'Modified') {
                dateText = `Modified: ${startDay} - ${endDay}`;
            }
            else {
                dateText = `Created: ${startDay} - ${endDay}`;
            }
            await expect(searchPage.searchFilters.dateFilter).toContainText(dateText, { ignoreCase: true });
        }
    }
    async isModifiedTabSelected() {
        return this.modifiedTab.getAttribute('aria-selected');
    }
    async isSearchTabSelected() {
        return this.createdTab.getAttribute('aria-selected');
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersLocation extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersLocation.rootElement);
    }
    addOptionInput = this.getChild(`[data-automation-id$='adf-search-chip-autocomplete-input']`);
    async filterByLocation(page, location) {
        await page.searchFilters.locationFilter.click();
        await page.searchFiltersLocation.addOptionInput.fill(location);
        await page.page.keyboard.press('Enter');
        await page.searchFilters.menuCardApply.click();
        await page.dataTable.progressBarWaitForReload();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersLogic extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersLogic.rootElement);
    }
    matchAllInput = this.getChild(`[placeholder$='Results will match all words entered here']`);
    matchAnyInput = this.getChild(`[placeholder$='Results will match any words entered here']`);
    excludeInput = this.getChild(`[placeholder$='Results will exclude matches with these words']`);
    matchExactInput = this.getChild(`[placeholder$='Results will match this entire phrase']`);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersProperties extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersProperties.rootElement);
    }
    operatorButton = this.getChild(`.adf-search-properties-file-size-operator`);
    fileSizeInput = this.getChild(`[placeholder$='Enter file size']`);
    unitButton = this.getChild(`.adf-search-properties-file-size-unit`);
    fileTypeInput = this.getChild(`[placeholder$='File Type']`);
    atLeastOption = this.page.locator(`mat-option`, { hasText: 'At Least' });
    atMostOption = this.page.locator(`mat-option`, { hasText: 'At Most' });
    exactlyOption = this.page.locator(`mat-option`, { hasText: 'Exactly' });
    kbUnit = this.page.locator(`mat-option`, { hasText: 'KB' });
    mbUnit = this.page.locator(`mat-option`, { hasText: 'MB' });
    gbUnit = this.page.locator(`mat-option`, { hasText: 'GB' });
    dropdownOptions = this.page.locator(`mat-option`);
    async setPropertiesParameters(page, operator, unit, fileSizeInputText, fileTypeInputText) {
        await page.searchFilters.propertiesFilter.click();
        if (operator) {
            await this.operatorButton?.click();
            switch (operator) {
                case 'At Least':
                    await this.atLeastOption?.click();
                    break;
                case 'At Most':
                    await this.atMostOption?.click();
                    break;
                case 'Exactly':
                    await this.exactlyOption?.click();
                    break;
            }
        }
        if (unit) {
            await this.unitButton?.click();
            switch (unit) {
                case 'KB':
                    await this.kbUnit?.click();
                    break;
                case 'MB':
                    await this.mbUnit?.click();
                    break;
                case 'GB':
                    await this.gbUnit?.click();
                    break;
            }
        }
        if (fileSizeInputText) {
            await this.fileSizeInput?.fill(fileSizeInputText);
        }
        if (fileTypeInputText) {
            await this.fileTypeInput?.fill(fileTypeInputText);
            await this.dropdownOptions.first().click();
        }
        await page.searchFilters.menuCardApply.click();
        await page.dataTable.progressBarWaitForReload();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchFiltersTags extends BaseComponent {
    static rootElement = '.adf-search-filter-menu-card';
    constructor(page) {
        super(page, SearchFiltersTags.rootElement);
    }
    addOptionInput = this.getChild(`[data-automation-id$='adf-search-chip-autocomplete-input']`);
    async filterByTag(page, tag) {
        await page.searchFilters.tagsFilter.click();
        await page.searchFiltersTags.addOptionInput.fill(tag);
        await page.page.keyboard.press('Enter');
        await page.searchFilters.menuCardApply.click();
        await page.dataTable.progressBarWaitForReload();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class Breadcrumb extends BaseComponent {
    static rootElement = 'adf-breadcrumb';
    items = this.getChild('.adf-breadcrumb-item');
    currentItem = this.getChild('.adf-breadcrumb-item-current');
    getItemByTitle = (name) => this.getChild(`.adf-breadcrumb-item[title=${name}]`);
    constructor(page) {
        super(page, Breadcrumb.rootElement);
    }
    async getAllItems() {
        const itemElements = await this.page.$$('adf-breadcrumb .adf-breadcrumb-item');
        const itemTexts = await Promise.all(itemElements.map(async (elem) => {
            const text = await elem.innerText();
            return text.split('\nchevron_right')[0];
        }));
        return itemTexts;
    }
    async clickItem(name) {
        const elem = this.getChild(`.adf-breadcrumb-item[title=${name}]`);
        await elem.click();
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SidenavComponent extends BaseComponent {
    static rootElement = 'app-sidenav';
    personalFiles = this.getChild(`[data-automation-id='app.navbar.personalFiles']`);
    myLibraries = this.getChild(`[data-automation-id='app.navbar.libraries.files']`);
    favoriteLibraries = this.getChild(`[data-automation-id='app.navbar.libraries.favorite']`);
    shared = this.getChild(`[data-automation-id='app.navbar.shared']`);
    recentFiles = this.getChild(`[data-automation-id='app.navbar.recentFiles']`);
    favorites = this.getChild(`[data-automation-id='app.navbar.favorites']`);
    trash = this.getChild(`[data-automation-id='app.navbar.trashcan']`);
    sidenavToggle = this.getChild(`.aca-sidenav-header-title-logo`);
    sidenavExpand = this.page.getByTitle('Expand navigation menu');
    expandedSidenav = this.page.locator(`[data-automation-id='expanded']`);
    constructor(page) {
        super(page, SidenavComponent.rootElement);
    }
    async isActive(name) {
        const cssClass = await this.getLinkLabel(name).getAttribute('class');
        return cssClass.includes('action-button--active');
    }
    async openPanel(name) {
        await this.getLinkLabel(name).click();
    }
    getLinkLabel(name) {
        switch (name) {
            case SIDEBAR_LABELS.PERSONAL_FILES:
                return this.personalFiles;
            case SIDEBAR_LABELS.MY_LIBRARIES:
                return this.myLibraries;
            case SIDEBAR_LABELS.FAVORITE_LIBRARIES:
                return this.favoriteLibraries;
            case SIDEBAR_LABELS.SHARED_FILES:
                return this.shared;
            case SIDEBAR_LABELS.RECENT_FILES:
                return this.recentFiles;
            case SIDEBAR_LABELS.FAVORITES:
                return this.favorites;
            case SIDEBAR_LABELS.TRASH:
                return this.trash;
            default:
                return this.personalFiles;
        }
    }
    async isSidenavExpanded() {
        await this.page.waitForTimeout(timeouts.tiny);
        return this.expandedSidenav.isVisible();
    }
    async expandSideNav() {
        const expanded = await this.isSidenavExpanded();
        if (!expanded) {
            await this.sidenavExpand.click();
            await this.expandedSidenav.waitFor({ state: 'attached' });
        }
    }
    async collapseSideNav() {
        const expanded = await this.isSidenavExpanded();
        if (expanded) {
            await this.sidenavToggle.click();
            await this.expandedSidenav.waitFor({ state: 'detached' });
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class ErrorComponent extends BaseComponent {
    static rootElement = 'aca-page-layout';
    genericError = this.getChild('aca-generic-error');
    genericErrorTitle = this.getChild('.generic-error__title');
    constructor(page) {
        super(page, ErrorComponent.rootElement);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class BasePage extends PlaywrightBase {
    pageUrl;
    urlRequest;
    snackBar;
    spinner;
    constructor(page, pageUrl, urlRequest) {
        super(page);
        this.pageUrl = pageUrl;
        this.urlRequest = urlRequest;
        this.snackBar = new SnackBarComponent(this.page);
        this.spinner = new SpinnerComponent(this.page);
    }
    /**
     * Method which navigate to appropriate page or remoteURL
     *
     * @param options object with configurable options
     * @property {string} query if you would like to navigate to page which support query,
     * then pass it in this option - e.g. '?appName=content'
     * @property {boolean} waitForRequest if you would like to NOT wait for request (which need to be passed
     * in the constructor of the page), then pass false. By default it'll wait for request to be fulfilled.
     * @property {'networkidle' | 'commit' | 'load' | 'domcontentloaded'} waitUntil by default will wait until 'networkidle' but you can change it if needed
     * @property {string} remoteUrl if you need to navigate to third part site, then you need to pass all of the URL in this option
     */
    async navigate(options) {
        const actualOptions = {
            query: '',
            waitForRequest: true,
            remoteUrl: '',
            waitUntil: 'load',
            ...options
        };
        if (actualOptions.remoteUrl) {
            await this.page.goto(actualOptions.remoteUrl, {
                waitUntil: actualOptions.waitUntil
            });
        }
        else if (this.urlRequest && actualOptions.waitForRequest) {
            await Promise.all([
                this.page.goto(`./#/${this.pageUrl}${actualOptions.query}`, { waitUntil: 'load' }),
                this.page.waitForResponse(this.urlRequest)
            ]);
        }
        else {
            await this.page.goto(`./#/${this.pageUrl}${actualOptions.query}`, {
                waitUntil: actualOptions.waitUntil,
                timeout: 60000
            });
        }
        await this.spinner.waitForReload();
    }
    async reload(options) {
        const actualOptions = {
            waitUntil: 'networkidle',
            ...options
        };
        await this.page.reload(actualOptions);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class LoginPage extends BasePage {
    static pageUrl = 'login';
    constructor(page) {
        super(page, LoginPage.pageUrl);
    }
    username = this.page.locator('#username');
    password = this.page.locator('#password');
    submitButton = this.page.locator('#login-button');
    userProfileButton = this.page.locator('aca-user-menu button');
    userLogOutButton = this.page.locator('aca-logout button');
    passwordVisibility = this.page.locator('.adf-login-password-icon');
    async loginUser(userData, options) {
        if (options?.withNavigation) {
            await this.navigate();
        }
        await this.username.fill(userData.username);
        await this.password.fill(userData.password);
        await this.submitButton.click();
        if (options?.waitForLoading) {
            await Promise.all([this.page.waitForLoadState('domcontentloaded'), this.spinner.waitForReload()]);
        }
    }
    async logoutUser() {
        await this.userProfileButton.click();
        await this.userLogOutButton.click();
    }
    async isPasswordDisplayed() {
        const type = await this.password.getAttribute('type');
        return type === 'text';
    }
    async verifyUserLogin() {
        if (await this.username.isVisible()) {
            await this.page.reload({ waitUntil: 'load' });
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class NodesPage extends BasePage {
    static pageUrl = 'nodes';
    constructor(page) {
        super(page, NodesPage.pageUrl);
    }
    toolbar = new ToolbarComponent(this.page);
    manageRulesDialog = new ManageRulesDialogComponent(this.page);
    actionsDropdown = new ActionsDropdownComponent(this.page);
    conditionsDropdown = new ConditionComponent(this.page);
    manageRules = new ManageRules(this.page);
    contentNodeSelectorDialog = new ContentNodeSelectorDialog(this.page);
    linkRulesDialog = new LinkRulesDialog(this.page);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class PersonalFilesPage extends BasePage {
    static pageUrl = 'personal-files';
    constructor(page) {
        super(page, PersonalFilesPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    contentNodeSelector = new ContentNodeSelectorDialog(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    passwordDialog = new PasswordOverlayDialogComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    breadcrumb = new Breadcrumb(this.page);
    sidenav = new SidenavComponent(this.page);
    createFromTemplateDialogComponent = new CreateFromTemplateDialogComponent(this.page);
    pagination = new PaginationComponent(this.page);
    errorDialog = new ErrorComponent(this.page);
    shareDialog = new ShareDialogComponent(this.page);
    confirmDialog = new AdfConfirmDialogComponent(this.page);
    infoDrawer = new AdfInfoDrawerComponent(this.page);
    uploadNewVersionDialog = new UploadNewVersionDialog(this.page);
    manageVersionsDialog = new ManageVersionsDialog(this.page);
    uploadDialog = new UploadDialog(this.page);
    snackBar = new SnackBarComponent(this.page);
    editDialog = new EditDialog(this.page);
    async selectCreateFolder() {
        await this.acaHeader.createButton.click();
        await this.matMenu.createFolder.click();
    }
    async closeMenu() {
        await this.page.keyboard.press('Escape');
    }
    async waitForPageLoad() {
        await this.page.waitForURL(`**/${PersonalFilesPage.pageUrl}`);
    }
    async clickMoreActionsButton(buttonLabel) {
        await this.acaHeader.clickMoreActions();
        await this.matMenu.clickMenuItem(buttonLabel);
    }
    async copyOrMoveContentInDatatable(sourceFileList, destinationName, operation = 'Copy') {
        await this.page.keyboard.down('Control');
        for (const sourceName of sourceFileList) {
            await this.dataTable.selectItems(sourceName);
        }
        await this.page.keyboard.up('Control');
        await this.clickMoreActionsButton(operation);
        await this.contentNodeSelector.selectDestination(destinationName);
        await this.contentNodeSelector.actionButton.click();
    }
    async selectItemsAndToggleFavorite(item, action) {
        for (const itemToSelect of item) {
            await this.dataTable.selectItems(itemToSelect);
        }
        await this.acaHeader.clickMoreActions();
        await this.matMenu.clickMenuItem(action);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class MyLibrariesPage extends BasePage {
    static pageUrl = 'libraries';
    constructor(page) {
        super(page, MyLibrariesPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    libraryDialog = new AdfLibraryDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    libraryDetails = new AdfInfoDrawerComponent(this.page);
    viewer = new ViewerComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    copyMoveDialog = new ContentNodeSelectorDialog(this.page);
    breadcrumb = new Breadcrumb(this.page);
    sidenav = new SidenavComponent(this.page);
    contentNodeSelector = new ContentNodeSelectorDialog(this.page);
    createFromTemplateDialogComponent = new CreateFromTemplateDialogComponent(this.page);
    confirmDialogComponent = new AdfConfirmDialogComponent(this.page);
    async selectCreateLibrary() {
        await this.acaHeader.createButton.click();
        await this.matMenu.createLibrary.click();
    }
    async clickMoreActionsButton(buttonLabel) {
        await this.acaHeader.clickMoreActions();
        await this.matMenu.clickMenuItem(buttonLabel);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class RecentFilesPage extends BasePage {
    static pageUrl = 'recent-files';
    constructor(page) {
        super(page, RecentFilesPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    sidenav = new SidenavComponent(this.page);
    breadcrumb = new Breadcrumb(this.page);
    infoDrawer = new AdfInfoDrawerComponent(this.page);
    contentNodeSelector = new ContentNodeSelectorDialog(this.page);
    manageVersionsDialog = new ManageVersionsDialog(this.page);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SharedPage extends BasePage {
    static pageUrl = 'shared';
    constructor(page) {
        super(page, SharedPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    sidenav = new SidenavComponent(this.page);
    breadcrumb = new Breadcrumb(this.page);
    infoDrawer = new AdfInfoDrawerComponent(this.page);
    manageVersionsDialog = new ManageVersionsDialog(this.page);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchPage extends BasePage {
    static pageUrl = 'search';
    constructor(page) {
        super(page, SearchPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    searchInput = new SearchInputComponent(this.page);
    searchOverlay = new SearchOverlayComponent(this.page);
    searchSortingPicker = new SearchSortingPicker(this.page);
    searchFilters = new SearchFilters(this.page);
    searchFiltersTags = new SearchFiltersTags(this.page);
    searchFiltersCategories = new SearchFiltersCategories(this.page);
    searchFiltersDate = new SearchFiltersDate(this.page);
    searchFiltersLocation = new SearchFiltersLocation(this.page);
    searchFiltersProperties = new SearchFiltersProperties(this.page);
    searchFiltersLogic = new SearchFiltersLogic(this.page);
    sidenav = new SidenavComponent(this.page);
    confirmDialogComponent = new AdfConfirmDialogComponent(this.page);
    uploadNewVersionDialog = new UploadNewVersionDialog(this.page);
    manageVersionsDialog = new ManageVersionsDialog(this.page);
    async searchWithin(searchText, searchType) {
        await this.acaHeader.searchButton.click();
        await this.clickSearchButton();
        switch (searchType) {
            case 'files':
                await this.searchOverlay.checkOnlyFiles();
                break;
            case 'folders':
                await this.searchOverlay.checkOnlyFolders();
                break;
            case 'filesAndFolders':
                await this.searchOverlay.checkFilesAndFolders();
                break;
            case 'libraries':
                await this.searchOverlay.checkLibraries();
                break;
            default:
                break;
        }
        await this.searchOverlay.searchFor(searchText);
        await this.dataTable.progressBarWaitForReload();
    }
    async clickSearchButton() {
        await this.searchInput.searchButton.click({ force: true });
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class FavoritesPage extends BasePage {
    static pageUrl = 'favorites';
    constructor(page) {
        super(page, FavoritesPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    sidenav = new SidenavComponent(this.page);
    pagination = new PaginationComponent(this.page);
    breadcrumb = new Breadcrumb(this.page);
    infoDrawer = new AdfInfoDrawerComponent(this.page);
    manageVersionsDialog = new ManageVersionsDialog(this.page);
    async waitForPageLoad() {
        await this.page.waitForURL(`**/${FavoritesPage.pageUrl}`);
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class TrashPage extends BasePage {
    static pageUrl = 'trashcan';
    constructor(page) {
        super(page, TrashPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    sidenav = new SidenavComponent(this.page);
    breadcrumb = new Breadcrumb(this.page);
    pagination = new PaginationComponent(this.page);
    deleteDialog = new AdfDeleteTrashComponent(this.page);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class FavoritesLibrariesPage extends BasePage {
    static pageUrl = 'favorite/libraries';
    constructor(page) {
        super(page, FavoritesLibrariesPage.pageUrl);
    }
    acaHeader = new AcaHeader(this.page);
    matMenu = new MatMenuComponent(this.page);
    folderDialog = new AdfFolderDialogComponent(this.page);
    dataTable = new DataTableComponent(this.page);
    viewer = new ViewerComponent(this.page);
    viewerDialog = new ViewerOverlayDialogComponent(this.page);
    sidenav = new SidenavComponent(this.page);
    confirmDialogComponent = new AdfConfirmDialogComponent(this.page);
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const env$2 = process.env;
const testEmailDomain = env$2.E2E_EMAIL_DOMAIN;
const users = {
    hruser: {
        username: env$2.HR_USER,
        password: env$2.HR_USER_PASSWORD
    },
    admin: {
        username: env$2.ADMIN_EMAIL,
        password: env$2.ADMIN_PASSWORD
    }
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
async function globalSetup(config) {
    const { use } = config.projects[0];
    await removeOutputFolders();
    await createOutputFolders();
    if (use.users) {
        for (const user of use.users) {
            if (users[user].username) {
                const browser = await chromium.launch();
                const page = await browser.newPage();
                const loginPage = new LoginPage(page);
                await page.goto(use.baseURL);
                await loginPage.loginUser({ username: users[user].username, password: users[user].password }, {
                    withNavigation: false,
                    waitForLoading: true
                });
                await page.context().storageState({ path: `${paths.userStates}/${user}UserState.json` });
                await browser.close();
            }
            else {
                throw new Error(`Add credentials for ${user} to you .env file!`);
            }
        }
    }
}
async function createOutputFolders() {
    for (const path in paths) {
        if (!fs__default.existsSync(paths[path])) {
            fs__default.mkdirSync(paths[path], { recursive: true });
        }
    }
}
async function removeOutputFolders() {
    if (fs__default.existsSync(paths.rootFolder)) {
        fs__default.rmdirSync(paths.rootFolder, { recursive: true });
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const { env: env$1 } = process;
const getReportPortalConfig = () => {
    const attributes = [
        { key: 'Job', value: `${env$1.GITHUB_JOB}` },
        { key: 'Build_type', value: `${env$1.GITHUB_EVENT_NAME}` },
        { key: 'Repository', value: `${env$1.GITHUB_REPOSITORY}` },
        { key: 'Branch', value: `${env$1.GITHUB_HEAD_REF || env$1.GITHUB_REF}` }
    ];
    const launch = `GitHub Actions - ACA`;
    return {
        endpoint: env$1.REPORT_PORTAL_URL,
        apiKey: env$1.REPORT_PORTAL_TOKEN,
        project: 'alfresco-content-app',
        launch,
        includeTestSteps: true,
        restClientConfig: {
            timeout: timeouts.extendedTest
        },
        attributes,
        description: `[Run on GitHub Actions ${env$1.GITHUB_RUN_ID}](${env$1.GITHUB_SERVER_URL}/${env$1.GITHUB_REPOSITORY}/actions/runs/${env$1.GITHUB_RUN_ID})`
    };
};
const getReporter = () => env$1.CI ? [['@reportportal/agent-js-playwright', getReportPortalConfig()], ['github']] : [['html']];

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
require('@alfresco/adf-cli/tooling').dotenvConfig();
const { env } = process;
const getGlobalConfig = {
    timeout: timeouts.globalTest,
    globalTimeout: timeouts.globalSpec,
    expect: {
        /**
         * Maximum time expect() should wait for the condition to be met.
         * For example in `await expect(locator).toHaveText();`
         */
        timeout: timeouts.medium
    },
    /* Run tests in files in parallel */
    fullyParallel: true,
    /* Fail the build on CI if you accidentally left test.only in the source code. */
    forbidOnly: !!env.CI,
    /* Retry on CI only */
    retries: env.CI ? 2 : 0,
    /* Opt out of parallel tests on CI. */
    workers: 3,
    /* Reporter to use. See https://playwright.dev/docs/test-reporters */
    reporter: [['list'], ...getReporter()],
    globalSetup: require.resolve('./global.setup'),
    testMatch: ['**/*.e2e.ts'],
    use: {
        /* Maximum time each action such as `click()` can take. Defaults to 0 (no limit). */
        actionTimeout: 0,
        /* Base URL to use in actions like `await page.goto('/')`. */
        baseURL: env.PLAYWRIGHT_E2E_HOST,
        headless: env.PLAYWRIGHT_HEADLESS === 'true' || !!env.CI,
        ignoreHTTPSErrors: true,
        bypassCSP: true,
        /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
        trace: 'retain-on-failure',
        video: 'retain-on-failure',
        screenshot: 'only-on-failure',
        launchOptions: {
            devtools: false,
            args: ['--no-sandbox', '--disable-site-isolation-trials']
        }
    },
    /* Configure projects for major browsers */
    projects: [
        {
            name: 'chromium',
            use: {
                ...devices['Desktop Chrome']
            }
        }
    ]
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class Person {
    id;
    password;
    firstName;
    lastName;
    email;
    enabled;
    properties;
    constructor(user) {
        this.id = user.username;
        this.password = user.password || user.username;
        this.firstName = user.firstName || user.username;
        this.lastName = user.lastName || user.username;
        this.email = user.email || `${user.username}@alfresco.com`;
        this.enabled = user.enabled || true;
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const { BASE_URL } = process.env;
const config = {
    authType: 'BASIC',
    hostBpm: BASE_URL,
    hostEcm: BASE_URL,
    provider: 'ECM',
    contextRoot: 'alfresco'
};
class ApiClientFactory {
    alfrescoApi;
    sites;
    upload;
    nodes;
    people;
    adminUsers;
    adminTenant;
    groups;
    queries;
    search;
    securityGroupsApi;
    securityMarksApi;
    contentClient;
    share;
    favorites;
    trashCan;
    commentsApi;
    queriesApi;
    categoriesApi;
    tagsApi;
    constructor() {
        this.alfrescoApi = new AlfrescoApi(config);
    }
    async setUpAcaBackend(userName, password) {
        await this.login(userName, password);
        this.sites = new SitesApi$1(this.alfrescoApi);
        this.upload = new UploadApi(this.alfrescoApi);
        this.nodes = new NodesApi$1(this.alfrescoApi);
        this.people = new PeopleApi(this.alfrescoApi);
        this.adminUsers = new AdminUsersApi(this.alfrescoApi);
        this.adminTenant = new AdminTenantsApi(this.alfrescoApi);
        this.groups = new GroupsApi(this.alfrescoApi);
        this.queries = new QueriesApi$1(this.alfrescoApi);
        this.search = new SearchApi(this.alfrescoApi);
        this.securityGroupsApi = new SecurityGroupsApi(this.alfrescoApi);
        this.securityMarksApi = new SecurityMarksApi(this.alfrescoApi);
        this.share = new SharedlinksApi(this.alfrescoApi);
        this.favorites = new FavoritesApi(this.alfrescoApi);
        this.trashCan = new TrashcanApi$1(this.alfrescoApi);
        this.commentsApi = new CommentsApi(this.alfrescoApi);
        this.queriesApi = new QueriesApi$1(this.alfrescoApi);
        this.categoriesApi = new CategoriesApi$1(this.alfrescoApi);
        this.tagsApi = new TagsApi$1(this.alfrescoApi);
        return this;
    }
    async tearDown() {
        await this.alfrescoApi.logout();
        return this;
    }
    async login(userName, password) {
        const predefinedUserKey = Object.keys(users).find((user) => user === userName || users[user].username === userName);
        const userToLog = predefinedUserKey ? users[predefinedUserKey] : undefined;
        let e;
        const user = userToLog?.username ?? userName;
        const userPassword = userToLog?.password ?? password;
        try {
            e = await this.alfrescoApi.login(user, userPassword);
        }
        catch (error) {
            console.error(`[API Client Factory] Log in user ${user} failed ${e}`);
            throw error;
        }
    }
    async loginUser(user) {
        let e;
        try {
            e = await this.alfrescoApi.login(user.username, user.password);
        }
        catch (error) {
            console.error(`[API Client Factory] Log in user ${user.username} failed ${e}`);
            throw error;
        }
    }
    async createUser(user) {
        const person = new Person(user);
        const peopleApi = new PeopleApi(this.alfrescoApi);
        try {
            return peopleApi.createPerson(person);
        }
        catch (error) {
            console.error('[API Client Factory] createUser failed : ', error);
            return null;
        }
    }
    async changePassword(username, newPassword) {
        const peopleApi = new PeopleApi(this.alfrescoApi);
        try {
            return peopleApi.updatePerson(username, { password: newPassword });
        }
        catch (error) {
            console.error('[API Client Factory] changePassword failed : ', error);
            return null;
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class RulesApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new RulesApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    callApi(path, httpMethod, body = {}) {
        // APIs used by this service are still private and not yet available for public use
        const params = [{}, {}, {}, {}, body, ['application/json'], ['application/json']];
        return this.apiService.alfrescoApi.contentPrivateClient.callApi(path, httpMethod, ...params);
    }
    async createRule(nodeId, rule, ruleSetId = '-default-') {
        const response = await this.callApi(`/nodes/${nodeId}/rule-sets/${ruleSetId}/rules`, 'POST', { ...rule });
        return response.entry;
    }
    async createRandomRule(folderId, ruleName) {
        const randomActionsIndex = crypto$1.randomInt(0, ActionTypes.actions.length);
        const randomAction = ActionTypes.actions[randomActionsIndex];
        return this.createRule(folderId, {
            name: ruleName,
            isEnabled: true,
            actions: [randomAction]
        });
    }
    async createRandomRuleWithMultipleConditions(folderId, ruleName, numOfConditions) {
        if (numOfConditions > ConditionsTypes.conditions.length) {
            numOfConditions = ConditionsTypes.conditions.length;
        }
        const randomActionsIndex = crypto$1.randomInt(0, ActionTypes.actions.length);
        const randomAction = ActionTypes.actions[randomActionsIndex];
        const conditionsArray = [];
        for (let i = 0; i < numOfConditions; i++) {
            const randomIndex = crypto$1.randomInt(0, ConditionsTypes.conditions.length);
            const randomCondition = ConditionsTypes.conditions[randomIndex];
            conditionsArray.push(randomCondition);
        }
        return this.createRule(folderId, {
            name: ruleName,
            isEnabled: true,
            actions: [randomAction],
            conditions: {
                inverted: false,
                booleanMode: 'and',
                compositeConditions: conditionsArray
            }
        });
    }
    async createRandomRuleWithMultipleActions(folderId, ruleName, numOfActions) {
        if (numOfActions > ActionTypes.actions.length) {
            numOfActions = ActionTypes.actions.length;
        }
        const actionsArray = [];
        for (let i = 0; i < numOfActions; i++) {
            const randomIndex = crypto$1.randomInt(0, ActionTypes.actions.length);
            const randomAction = ActionTypes.actions[randomIndex];
            actionsArray.push(randomAction);
        }
        return this.createRule(folderId, {
            name: ruleName,
            isEnabled: true,
            actions: actionsArray
        });
    }
    async createRandomComplexRule(folderId, ruleName, numOfConditions, numOfActions, ruleDescription) {
        if (numOfConditions > ConditionsTypes.conditions.length) {
            numOfConditions = ConditionsTypes.conditions.length;
        }
        const conditionsArray = [];
        for (let i = 0; i < numOfConditions; i++) {
            const randomIndex = crypto$1.randomInt(0, ConditionsTypes.conditions.length);
            const randomCondition = ConditionsTypes.conditions[randomIndex];
            conditionsArray.push(randomCondition);
        }
        if (numOfActions > ActionTypes.actions.length) {
            numOfActions = ActionTypes.actions.length;
        }
        const actionsArray = [];
        for (let i = 0; i < numOfActions; i++) {
            const randomIndex = crypto$1.randomInt(0, ActionTypes.actions.length);
            const randomAction = ActionTypes.actions[randomIndex];
            actionsArray.push(randomAction);
        }
        return this.createRule(folderId, {
            name: ruleName,
            description: ruleDescription,
            isEnabled: true,
            actions: actionsArray,
            conditions: {
                inverted: false,
                booleanMode: 'and',
                compositeConditions: conditionsArray
            }
        });
    }
    async createRuleWithRandomAspects(folderId, ruleName) {
        return this.createRule(folderId, {
            name: ruleName,
            isEnabled: true,
            actions: [
                {
                    actionDefinitionId: 'add-features',
                    params: {
                        'aspect-name': 'sc:controlsAreClearance'
                    }
                },
                {
                    actionDefinitionId: 'add-features',
                    params: {
                        'aspect-name': 'sfdc:objectModel'
                    }
                },
                {
                    actionDefinitionId: 'add-features',
                    params: {
                        'aspect-name': 'sfdc:folder'
                    }
                }
            ]
        });
    }
    async createRuleWithDestinationFolder(folderId, ruleName, actionType, destinationFolderId) {
        return this.createRule(folderId, {
            name: ruleName,
            isEnabled: true,
            actions: [
                {
                    actionDefinitionId: actionType,
                    params: {
                        'destination-folder': destinationFolderId
                    }
                }
            ]
        });
    }
}
class ActionTypes {
    key;
    value;
    static ADDFEATURES = new ActionTypes('ADDFEATURES', {
        actionDefinitionId: 'add-features',
        params: { 'aspect-name': 'cm:thumbnailed' }
    });
    static CHECKIN = new ActionTypes('CHECKIN', {
        actionDefinitionId: 'check-in',
        params: {
            description: 'test',
            minorChange: true
        }
    });
    static SPECIALISETYPE = new ActionTypes('SPECIALISETYPE', {
        actionDefinitionId: 'specialise-type',
        params: { 'type-name': 'sys:base' }
    });
    static RECORDABLEVERSION = new ActionTypes('RECORDABLEVERSION', {
        actionDefinitionId: 'recordable-version-config',
        params: { version: 'ALL' }
    });
    static SETPROPERTYVALUE = new ActionTypes('SETPROPERTYVALUE', {
        actionDefinitionId: 'set-property-value',
        params: { property: 'dl:ganttPercentComplete', value: 'test' }
    });
    static actions = [
        ActionTypes.ADDFEATURES.value,
        ActionTypes.CHECKIN.value,
        ActionTypes.RECORDABLEVERSION.value,
        ActionTypes.SPECIALISETYPE.value,
        ActionTypes.SETPROPERTYVALUE.value
    ];
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}
class ConditionsTypes {
    key;
    value;
    static MIMETYPE = new ConditionsTypes('MIMETYPE', {
        inverted: false,
        booleanMode: 'and',
        simpleConditions: [
            {
                field: 'mimetype',
                comparator: 'equals',
                parameter: 'video/3gpp'
            }
        ]
    });
    static CMNAME = new ConditionsTypes('CM:NAME', {
        inverted: false,
        booleanMode: 'and',
        simpleConditions: [
            {
                field: 'cm:name',
                comparator: 'equals',
                parameter: 'testname'
            }
        ]
    });
    static SIZE = new ConditionsTypes('SIZE', {
        inverted: false,
        booleanMode: 'and',
        simpleConditions: [
            {
                field: 'size',
                comparator: 'equals',
                parameter: '345'
            }
        ]
    });
    static TAG = new ConditionsTypes('TAG', {
        inverted: false,
        booleanMode: 'and',
        simpleConditions: [
            {
                field: 'tag',
                comparator: 'equals',
                parameter: 'testtag'
            }
        ]
    });
    static conditions = [ConditionsTypes.MIMETYPE.value, ConditionsTypes.CMNAME.value, ConditionsTypes.SIZE.value, ConditionsTypes.TAG.value];
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class FileActionsApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new FileActionsApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async uploadFile(fileLocation, fileName, parentFolderId) {
        const file = fs.createReadStream(fileLocation);
        return this.apiService.upload.uploadFile(file, '', parentFolderId, null, {
            name: fileName,
            nodeType: 'cm:content',
            renditions: 'doclib'
        });
    }
    async uploadFileWithRename(fileLocation, newName, parentId = '-my-', title = '', description = '') {
        const file = fs.createReadStream(fileLocation);
        const nodeProps = {
            properties: {
                'cm:title': title,
                'cm:description': description
            }
        };
        const opts = {
            name: newName,
            nodeType: 'cm:content'
        };
        try {
            return this.apiService.upload.uploadFile(file, '', parentId, nodeProps, opts);
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async lockNodes(nodeIds, lockType = 'ALLOW_OWNER_CHANGES') {
        try {
            for (const nodeId of nodeIds) {
                await this.apiService.nodes.lockNode(nodeId, { type: lockType });
            }
        }
        catch { }
    }
    async getNodeById(id) {
        try {
            return this.apiService.nodes.getNode(id);
        }
        catch {
            return null;
        }
    }
    async getNodeProperty(nodeId, property) {
        try {
            const node = await this.getNodeById(nodeId);
            return node.entry.properties?.[property] || '';
        }
        catch {
            return '';
        }
    }
    async getLockType(nodeId) {
        try {
            const lockType = await this.getNodeProperty(nodeId, 'cm:lockType');
            return lockType || '';
        }
        catch {
            return '';
        }
    }
    async isFileLockedWriteWithRetry(nodeId, expect) {
        const data = {
            expect: expect,
            retry: 5
        };
        let isLocked = false;
        try {
            const locked = async () => {
                isLocked = (await this.getLockType(nodeId)) === 'WRITE_LOCK';
                if (isLocked !== data.expect) {
                    return Promise.reject(isLocked);
                }
                else {
                    return Promise.resolve(isLocked);
                }
            };
            return await Utils.retryCall(locked, data.retry);
        }
        catch { }
        return isLocked;
    }
    async queryNodesNames(searchTerm) {
        const data = {
            query: {
                query: `cm:name:\"${searchTerm}*\"`,
                language: 'afts'
            },
            filterQueries: [{ query: `+TYPE:'cm:folder' OR +TYPE:'cm:content'` }]
        };
        try {
            return this.apiService.search.search(data);
        }
        catch {
            return new ResultSetPaging();
        }
    }
    async waitForNodes(searchTerm, data) {
        const predicate = (totalItems) => totalItems === data.expect;
        const apiCall = async () => {
            try {
                return (await this.queryNodesNames(searchTerm)).list.pagination.totalItems;
            }
            catch (error) {
                return 0;
            }
        };
        try {
            await waitForApi(apiCall, predicate, 30, 2500);
        }
        catch (error) {
            console.error(`Error: ${error}`);
        }
    }
    async updateNodeContent(nodeId, content, majorVersion = true, comment, newName) {
        try {
            const opts = {
                majorVersion: majorVersion,
                comment: comment,
                name: newName
            };
            return this.apiService.nodes.updateNodeContent(nodeId, content, opts);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.updateNodeContent.name}`, error);
            return Promise.reject(error);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SharedLinksApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new SharedLinksApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async shareFileById(id, expireDate) {
        try {
            const data = {
                nodeId: id,
                expiresAt: expireDate
            };
            return this.apiService.share.createSharedLink(data);
        }
        catch (error) {
            return null;
        }
    }
    async shareFilesByIds(ids, expireDate) {
        const sharedLinks = [];
        try {
            if (ids && ids.length > 0) {
                for (const id of ids) {
                    const sharedLink = await this.shareFileById(id, expireDate);
                    sharedLinks.push(sharedLink);
                }
            }
        }
        catch (error) {
            console.error(`SharedLinksApi shareFilesByIds : catch : `, error);
        }
        return sharedLinks;
    }
    async getSharedLinks(maxItems = 250) {
        try {
            const opts = {
                maxItems
            };
            return this.apiService.share.listSharedLinks(opts);
        }
        catch (error) {
            console.error(`SharedLinksApi getSharedLinks : catch : `, error);
            return new SharedLinkPaging();
        }
    }
    async waitForFilesToBeShared(filesIds) {
        try {
            const sharedFile = async () => {
                const sharedFiles = (await this.getSharedLinks()).list.entries.map((link) => link.entry.nodeId);
                const foundItems = filesIds.every((id) => sharedFiles.includes(id));
                if (foundItems) {
                    return Promise.resolve(foundItems);
                }
                else {
                    return Promise.reject(foundItems);
                }
            };
            return await Utils.retryCall(sharedFile);
        }
        catch (error) {
            console.error(`SharedLinksApi waitForFilesToBeShared :  catch : ${error}`);
            console.error(`\tWait timeout reached waiting for files to be shared`);
        }
    }
    async getSharedIdOfNode(fileId) {
        try {
            const sharedLinksEntries = (await this.getSharedLinks())?.list.entries;
            const found = sharedLinksEntries.find((sharedLink) => sharedLink.entry.nodeId === fileId);
            return found?.entry.id;
        }
        catch (error) {
            console.error(`SharedLinksApi getSharedIdOfNode : catch : `, error);
            return null;
        }
    }
    async unshareFileById(fileId) {
        try {
            const sharedId = await this.getSharedIdOfNode(fileId);
            return this.apiService.share.deleteSharedLink(sharedId);
        }
        catch (error) {
            console.error(`SharedLinksApi unshareFileById : catch : `, error);
        }
    }
    async waitForFilesToNotBeShared(filesIds) {
        try {
            const sharedFile = async () => {
                const sharedFiles = (await this.getSharedLinks()).list.entries.map((link) => link.entry.nodeId);
                const foundItems = filesIds.some((id) => {
                    return sharedFiles.includes(id);
                });
                if (foundItems) {
                    return Promise.reject(foundItems);
                }
                else {
                    return Promise.resolve(foundItems);
                }
            };
            return await Utils.retryCall(sharedFile);
        }
        catch (error) {
            console.error(`SharedLinksApi waitForFilesToNotBeShared :  catch : ${error}`);
            console.error(`\tWait timeout reached waiting for files to no longer be shared`);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class FavoritesPageApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new FavoritesPageApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async addFavoriteById(nodeType, id) {
        const guid = nodeType === 'site' ? (await this.apiService.sites.getSite(id)).entry.guid : id;
        const data = {
            target: {
                [nodeType]: {
                    guid: guid
                }
            }
        };
        return this.apiService.favorites.createFavorite('-me-', data);
    }
    async addFavoritesByIds(nodeType, ids) {
        const favorites = [];
        try {
            if (ids && ids.length > 0) {
                for (const id of ids) {
                    const favorite = await this.addFavoriteById(nodeType, id);
                    favorites.push(favorite);
                }
            }
        }
        catch { }
        return favorites;
    }
    async getFavorites(username) {
        try {
            return this.apiService.favorites.listFavorites(username);
        }
        catch {
            return new FavoritePaging();
        }
    }
    async isFavorite(username, nodeId) {
        try {
            return JSON.stringify((await this.getFavorites(username)).list.entries).includes(nodeId);
        }
        catch {
            return false;
        }
    }
    async isFavoriteWithRetry(username, nodeId, data) {
        let isFavorite = false;
        try {
            const favorite = async () => {
                isFavorite = await this.isFavorite(username, nodeId);
                if (isFavorite !== data.expect) {
                    return Promise.reject(isFavorite);
                }
                else {
                    return Promise.resolve(isFavorite);
                }
            };
            return await Utils.retryCall(favorite);
        }
        catch (error) { }
        return isFavorite;
    }
    async getFavoritesTotalItems(username) {
        try {
            return (await this.apiService.favorites.listFavorites(username)).list.pagination.totalItems;
        }
        catch {
            return -1;
        }
    }
    async waitForApi(username, data) {
        try {
            const favoriteFiles = async () => {
                const totalItems = await this.getFavoritesTotalItems(username);
                if (totalItems !== data.expect) {
                    return Promise.reject(totalItems);
                }
                else {
                    return Promise.resolve(totalItems);
                }
            };
            return await Utils.retryCall(favoriteFiles);
        }
        catch { }
    }
    async removeFavoritesByIds(username, ids) {
        try {
            if (ids && ids.length > 0) {
                for (const id of ids) {
                    await this.apiService.favorites.deleteFavorite(username, id);
                }
            }
        }
        catch (error) {
            console.error('FavoritesApi: removeFavoritesByIds failed ', error);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const NODE_TYPE_FILE = 'cm:content';
const NODE_TYPE_FOLDER = 'cm:folder';
const NODE_TITLE = 'cm:title';
const NODE_DESCRIPTION = 'cm:description';
function flattenNodeContentTree(content, relativePath = '/') {
    const { name, files, folders, title, description } = content;
    const aspectNames = ['cm:versionable'];
    let data = [];
    const properties = {
        [NODE_TITLE]: title,
        [NODE_DESCRIPTION]: description
    };
    if (name) {
        data = data.concat([
            {
                nodeType: NODE_TYPE_FOLDER,
                name,
                relativePath,
                properties
            }
        ]);
        relativePath = relativePath === '/' ? `/${name}` : `${relativePath}/${name}`;
    }
    if (folders) {
        const foldersData = folders
            .map((folder) => {
            const folderData = typeof folder === 'string' ? { name: folder } : folder;
            return flattenNodeContentTree(folderData, relativePath);
        })
            .reduce((nodesData, folderData) => nodesData.concat(folderData), []);
        data = data.concat(foldersData);
    }
    if (files) {
        const filesData = files.map((filename) => ({
            nodeType: NODE_TYPE_FILE,
            name: filename,
            relativePath,
            aspectNames
        }));
        data = data.concat(filesData);
    }
    return data;
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class NodesApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new NodesApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async createFolder(name, parentId = '-my-', title = '', description = '', author = '', aspectNames = null) {
        try {
            return await this.createNode('cm:folder', name, parentId, title, description, null, author, null, aspectNames);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFolder.name}`, error);
            return null;
        }
    }
    async createFile(name, parentId = '-my-', title = '', description = '', author = '', majorVersion = true, aspectNames = null) {
        try {
            return await this.createNode('cm:content', name, parentId, title, description, null, author, majorVersion, aspectNames);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFile.name}`, error);
            return null;
        }
    }
    async createFiles(names, relativePath = '/') {
        try {
            return await this.createContent({ files: names }, relativePath);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFiles.name}: ${error}`);
            return null;
        }
    }
    async createFolders(names, relativePath = '/') {
        try {
            return await this.createContent({ folders: names }, relativePath);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFolders.name}: ${error}`);
            return null;
        }
    }
    async deleteDeletedNode(name) {
        try {
            await this.apiService.trashCan.deleteDeletedNode(name);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteDeletedNode.name}: ${error}`);
        }
    }
    async createNode(nodeType, name, parentId = '-my-', title = '', description = '', imageProps = null, author = '', majorVersion = true, aspectNames = null) {
        if (!aspectNames) {
            aspectNames = ['cm:versionable']; // workaround for REPO-4772
        }
        const nodeBody = {
            name,
            nodeType,
            relativePath: '/',
            properties: {
                'cm:title': title,
                'cm:description': description,
                'cm:author': author
            },
            aspectNames
        };
        if (imageProps) {
            nodeBody.properties = Object.assign(nodeBody.properties, imageProps);
        }
        try {
            return this.apiService.nodes.createNode(parentId, nodeBody, {
                majorVersion
            });
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createNode.name}`, error);
            return null;
        }
    }
    async renameNode(nodeId, newName) {
        try {
            return this.apiService.nodes.updateNode(nodeId, { name: newName });
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.renameNode.name}`, error);
            return null;
        }
    }
    /**
     * Delete multiple nodes.
     * @param nodeIds The list of node IDs to delete.
     * @param permanent Delete permanently, without moving to the trashcan? (default: true)
     */
    async deleteNodes(nodeIds, permanent = true) {
        try {
            await this.apiService.nodes.deleteNodes(nodeIds, { permanent });
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteNodes.name}`, error);
        }
    }
    /**
     * Delete all nodes of the currently logged in user
     * @param userNodeId The id of User node, all child nodes of "userNodeId" will be gathered as a list and deleted ( e.g.: "-my-" - User Homes folder)
     */
    async deleteCurrentUserNodes() {
        try {
            const userNodes = (await this.getNodeChildren('-my-')).list.entries;
            const userNodesIds = userNodes.map((nodeChild) => nodeChild.entry.id);
            await this.deleteNodes(userNodesIds);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteCurrentUserNodes.name}`, error);
        }
    }
    async lockNodes(nodeIds, lockType = 'ALLOW_OWNER_CHANGES') {
        try {
            for (const nodeId of nodeIds) {
                await this.apiService.nodes.lockNode(nodeId, { type: lockType });
            }
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.lockNodes.name}`, error);
        }
    }
    async unlockNodes(nodeIds) {
        try {
            for (const nodeId of nodeIds) {
                await this.apiService.nodes.unlockNode(nodeId);
            }
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.unlockNodes.name}`, error);
        }
    }
    async createContent(content, relativePath = '/') {
        try {
            return this.apiService.nodes.createNode('-my-', flattenNodeContentTree(content, relativePath));
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createContent.name}`, error);
            return null;
        }
    }
    async getNodeById(id) {
        try {
            return this.apiService.nodes.getNode(id);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.getNodeById.name}`, error);
            return null;
        }
    }
    async getNodeIdFromParent(name, parentId) {
        try {
            const children = (await this.getNodeChildren(parentId)).list.entries;
            return children.find((elem) => elem.entry.name === name).entry.id || '';
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.getNodeIdFromParent.name}`, error);
            return '';
        }
    }
    async getNodeChildren(nodeId) {
        try {
            const opts = {
                include: ['properties']
            };
            return this.apiService.nodes.listNodeChildren(nodeId, opts);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.getNodeChildren.name}`, error);
            return null;
        }
    }
    async deleteNodeById(id, permanent = true) {
        try {
            await this.apiService.nodes.deleteNode(id, { permanent });
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteNodeById.name}`, error);
        }
    }
    async cleanupNodeTemplatesItems(nodeNames) {
        try {
            const templatesFolderId = await this.getNodeTemplatesFolderId();
            for (const nodeName of nodeNames) {
                const nodeId = await this.getNodeIdFromParent(nodeName, templatesFolderId);
                await this.deleteNodeById(nodeId);
            }
        }
        catch (error) {
            console.error('Admin Actions - cleanupNodeTemplatesItems failed : ', error);
        }
    }
    async cleanupSpaceTemplatesItems(nodeNames) {
        try {
            const spaceTemplatesNodeId = await this.getSpaceTemplatesFolderId();
            for (const nodeName of nodeNames) {
                const nodeId = await this.getNodeIdFromParent(nodeName, spaceTemplatesNodeId);
                await this.deleteNodeById(nodeId);
            }
        }
        catch (error) {
            console.error('Admin Actions - cleanupSpaceTemplatesFolder failed : ', error);
        }
    }
    async getNodeTemplatesFolderId() {
        try {
            return this.getNodeIdFromParent('Node Templates', await this.getDataDictionaryId());
        }
        catch (error) {
            console.error('Admin Actions - getNodeTemplatesFolderId failed : ', error);
            return '';
        }
    }
    async getSpaceTemplatesFolderId() {
        try {
            return this.getNodeIdFromParent('Space Templates', await this.getDataDictionaryId());
        }
        catch (error) {
            console.error('Admin Actions - getSpaceTemplatesFolderId failed : ', error);
            return '';
        }
    }
    async getDataDictionaryId() {
        return this.getNodeIdFromParent('Data Dictionary', '-root-').catch((error) => {
            console.error('Admin Actions - getDataDictionaryId failed : ', error);
            return '';
        });
    }
    async setGranularPermission(nodeId, inheritPermissions = false, username, role) {
        const data = {
            permissions: {
                isInheritanceEnabled: inheritPermissions,
                locallySet: [
                    {
                        authorityId: username,
                        name: role
                    }
                ]
            }
        };
        try {
            return this.apiService.nodes.updateNode(nodeId, data);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.setGranularPermission.name}`, error);
            return null;
        }
    }
    async removeUserAccessOnNodeTemplate(nodeName) {
        try {
            const templatesRootFolderId = await this.getNodeTemplatesFolderId();
            const nodeId = await this.getNodeIdFromParent(nodeName, templatesRootFolderId);
            return this.setInheritPermissions(nodeId, false);
        }
        catch (error) {
            console.error('Admin Actions - removeUserAccessOnNodeTemplate failed : ', error);
            return null;
        }
    }
    async removeUserAccessOnSpaceTemplate(nodeName) {
        try {
            const templatesRootFolderId = await this.getSpaceTemplatesFolderId();
            const nodeId = await this.getNodeIdFromParent(nodeName, templatesRootFolderId);
            return this.setInheritPermissions(nodeId, false);
        }
        catch (error) {
            console.error('Admin Actions - removeUserAccessOnSpaceTemplate failed : ', error);
            return null;
        }
    }
    async setInheritPermissions(nodeId, inheritPermissions) {
        const data = {
            permissions: {
                isInheritanceEnabled: inheritPermissions
            }
        };
        try {
            return this.apiService.nodes.updateNode(nodeId, data);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.setInheritPermissions.name}`, error);
            return null;
        }
    }
    async addAspects(nodeId, aspectNames) {
        try {
            return this.apiService.nodes.updateNode(nodeId, { aspectNames });
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.addAspects.name}`, error);
            return null;
        }
    }
    async createFileLink(originalNodeId, destinationId) {
        const name = (await this.getNodeById(originalNodeId)).entry.name;
        const nodeBody = {
            name: `Link to ${name}.url`,
            nodeType: 'app:filelink',
            properties: {
                'cm:destination': originalNodeId
            }
        };
        try {
            const link = await this.apiService.nodes.createNode(destinationId, nodeBody);
            await this.addAspects(originalNodeId, ['app:linked']);
            return link;
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFileLink.name}`, error);
            return null;
        }
    }
    async createFolderLink(originalNodeId, destinationId) {
        const name = (await this.getNodeById(originalNodeId)).entry.name;
        const nodeBody = {
            name: `Link to ${name}.url`,
            nodeType: 'app:folderlink',
            properties: {
                'cm:title': `Link to ${name}.url`,
                'cm:destination': originalNodeId,
                'cm:description': `Link to ${name}.url`,
                'app:icon': 'space-icon-link'
            }
        };
        try {
            const link = await this.apiService.nodes.createNode(destinationId, nodeBody);
            await this.addAspects(originalNodeId, ['app:linked']);
            return link;
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.createFolderLink.name}`, error);
            return null;
        }
    }
    async createLinkToFileName(originalFileName, originalFileParentId, destinationParentId) {
        destinationParentId ??= originalFileParentId;
        try {
            const nodeId = await this.getNodeIdFromParent(originalFileName, originalFileParentId);
            return this.createFileLink(nodeId, destinationParentId);
        }
        catch (error) {
            console.error('Admin Actions - createLinkToFileName failed : ', error);
            return null;
        }
    }
    async createLinkToFolderName(originalFolderName, originalFolderParentId, destinationParentId) {
        destinationParentId ??= originalFolderParentId;
        try {
            const nodeId = await this.getNodeIdFromParent(originalFolderName, originalFolderParentId);
            return this.createFolderLink(nodeId, destinationParentId);
        }
        catch (error) {
            console.error('Admin Actions - createLinkToFolderName failed : ', error);
            return null;
        }
    }
    async getNodeProperty(nodeId, property) {
        try {
            const node = await this.getNodeById(nodeId);
            return node.entry.properties?.[property] || '';
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.getNodeProperty.name}`, error);
            return '';
        }
    }
    async isFileShared(nodeId) {
        try {
            const sharedId = await this.getNodeProperty(nodeId, 'qshare:sharedId');
            return sharedId !== '';
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.isFileShared.name}`, error);
            return null;
        }
    }
    async getLockType(nodeId) {
        try {
            const lockType = await this.getNodeProperty(nodeId, 'cm:lockType');
            return lockType || '';
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.getLockType.name}`, error);
            return '';
        }
    }
    async isFileLockedWrite(nodeId) {
        try {
            return (await this.getLockType(nodeId)) === 'WRITE_LOCK';
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.isFileLockedWrite.name}`, error);
            return null;
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SitesApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new SitesApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async createSite(title, visibility, description, siteId) {
        const site = {
            title,
            visibility: visibility || Site.VisibilityEnum.PUBLIC,
            description: description,
            id: siteId || title
        };
        try {
            return this.apiService.sites.createSite(site);
        }
        catch (error) {
            console.error(`SitesApi createSite : catch : `, error);
            return null;
        }
    }
    async getDocLibId(siteId) {
        try {
            return (await this.apiService.sites.listSiteContainers(siteId)).list.entries[0].entry.id;
        }
        catch (error) {
            console.error(`SitesApi getDocLibId : catch : `, error);
            return null;
        }
    }
    /**
     * Delete multiple sites/libraries.
     * @param siteIds The list of the site/library IDs to delete.
     * @param permanent Delete permanently, without moving to the trashcan? (default: true)
     */
    async deleteSites(siteIds, permanent = true) {
        try {
            if (siteIds && siteIds.length > 0) {
                for (const siteId of siteIds) {
                    await this.apiService.sites.deleteSite(siteId, { permanent });
                }
            }
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteSites.name}`, error);
        }
    }
    async updateSiteMember(siteId, userId, role) {
        const siteRole = {
            role: role
        };
        try {
            return this.apiService.sites.updateSiteMembership(siteId, userId, siteRole);
        }
        catch (error) {
            console.error(`SitesApi updateSiteMember : catch : `, error);
            return new SiteMemberEntry();
        }
    }
    async addSiteMember(siteId, userId, role) {
        const memberBody = {
            id: userId,
            role: role
        };
        try {
            return this.apiService.sites.createSiteMembership(siteId, memberBody);
        }
        catch (error) {
            if (error.status === 409) {
                return this.updateSiteMember(siteId, userId, role);
            }
            else {
                console.error(`SitesApi addSiteMember : catch : `, error);
                return new SiteMemberEntry();
            }
        }
    }
    async createSiteMembershipRequestForPerson(personId, siteId) {
        const body = {
            id: siteId
        };
        try {
            return this.apiService.sites.createSiteMembershipRequestForPerson(personId, body);
        }
        catch (error) {
            console.error(`SitesApi createSiteMembershipRequestForPerson : catch : `, error);
            return null;
        }
    }
    async approveSiteMembershipRequest(siteId, inviteeId) {
        try {
            return this.apiService.sites.approveSiteMembershipRequest(siteId, inviteeId);
        }
        catch (error) {
            console.error(`SitesApi approveSiteMembershipRequest : catch : `, error);
            return null;
        }
    }
    async hasMembershipRequest(personId, siteId) {
        try {
            const requests = (await this.apiService.sites.listSiteMembershipRequestsForPerson(personId)).list.entries.map((e) => e.entry.id);
            return requests.includes(siteId);
        }
        catch (error) {
            console.error(`SitesApi hasMembershipRequest : catch : `, error);
            return null;
        }
    }
    async deleteSiteMember(siteId, userId) {
        try {
            return this.apiService.sites.deleteSiteMembership(siteId, userId);
        }
        catch (error) {
            console.error(`SitesApi deleteSiteMember : catch : `, error);
        }
    }
    async getSite(siteId) {
        try {
            return this.apiService.sites.getSite(siteId);
        }
        catch (error) {
            console.error(`SitesApi getSite : catch : `, error);
            return null;
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class SearchPageApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new SearchPageApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async querySearchFiles(username) {
        const data = {
            query: {
                query: '*',
                language: 'afts'
            },
            filterQueries: [
                { query: `cm:modified:[NOW/DAY-30DAYS TO NOW/DAY+1DAY]` },
                { query: `cm:modifier:${username} OR cm:creator:${username}` },
                { query: `TYPE:"content" AND -TYPE:"app:filelink" AND -TYPE:"fm:post"` }
            ]
        };
        try {
            return this.apiService.search.search(data);
        }
        catch {
            return new ResultSetPaging();
        }
    }
    async getTotalItems(username) {
        return (await this.querySearchFiles(username)).list.pagination.totalItems;
    }
    async waitForApi(username, data) {
        try {
            const searchFiles = async () => {
                const totalItems = await this.getTotalItems(username);
                if (totalItems !== data.expect) {
                    return Promise.reject(totalItems);
                }
                else {
                    return Promise.resolve(totalItems);
                }
            };
            return await Utils.retryCall(searchFiles);
        }
        catch { }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class TrashcanApi {
    apiService = new ApiClientFactory();
    static async initialize(userName, password) {
        const classObj = new TrashcanApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    /**
     * Empties the trashcan. Uses multiple batches 1000 nodes each.
     */
    async emptyTrashcan() {
        try {
            const nodes = await this.apiService.trashCan.listDeletedNodes({
                maxItems: 1000
            });
            if (nodes?.list?.entries?.length > 0) {
                const ids = nodes.list.entries.map((entries) => entries.entry.id);
                for (const nodeId of ids) {
                    await this.apiService.trashCan.deleteDeletedNode(nodeId);
                }
            }
        }
        catch (error) {
            console.error('User Actions - emptyTrashcan failed : ', error);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class QueriesApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new QueriesApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async waitForSites(searchTerm, data) {
        try {
            const sites = async () => {
                const totalItems = await this.findSitesTotalItems(searchTerm);
                if (totalItems !== data.expect) {
                    return Promise.reject(totalItems);
                }
                else {
                    return Promise.resolve(totalItems);
                }
            };
            return await Utils.retryCall(sites);
        }
        catch (error) {
            console.error(`QueriesApi waitForSites : catch : `);
            console.error(`\tExpected: ${data.expect} items, but found ${error}`);
            return null;
        }
    }
    async findSitesTotalItems(searchTerm) {
        try {
            const opts = {
                term: searchTerm,
                fields: ['title']
            };
            const sites = await this.apiService.queries.findSites(searchTerm, opts);
            return sites.list.pagination.totalItems;
        }
        catch (error) {
            console.error(`QueriesApi findSitesTotalItems : catch :`, error);
            return null;
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class CategoriesApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new CategoriesApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async createCategory(categoryId, categoryBodyCreate, opts) {
        try {
            return this.apiService.categoriesApi.createSubcategories(categoryId, categoryBodyCreate, opts);
        }
        catch (error) {
            console.error(error);
            return null;
        }
    }
    async deleteCategory(categoryId) {
        if (categoryId === null) {
            console.error('categoryId is null, skipping deletion');
            return;
        }
        try {
            await this.apiService.categoriesApi.deleteCategory(categoryId);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.deleteCategory.name}: ${error}`);
        }
    }
    async linkNodeToCategory(nodeId, categoryLinkBodyCreate, opts) {
        try {
            return this.apiService.categoriesApi.linkNodeToCategory(nodeId, categoryLinkBodyCreate, opts);
        }
        catch (error) {
            console.error(`${this.constructor.name} ${this.linkNodeToCategory.name}: ${error}`);
            return null;
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
class TagsApi {
    apiService;
    constructor() {
        this.apiService = new ApiClientFactory();
    }
    static async initialize(userName, password) {
        const classObj = new TagsApi();
        await classObj.apiService.setUpAcaBackend(userName, password);
        return classObj;
    }
    async createTags(tags) {
        try {
            return this.apiService.tagsApi.createTags(tags);
        }
        catch (error) {
            console.error(error);
            return null;
        }
    }
    async assignTagToNode(nodeId, tag) {
        try {
            return this.apiService.tagsApi.assignTagToNode(nodeId, tag);
        }
        catch (error) {
            console.error(error);
            return null;
        }
    }
    async deleteTags(tagIds) {
        try {
            for (const tagId of tagIds) {
                await this.apiService.tagsApi.deleteTag(tagId);
            }
        }
        catch (error) {
            console.error(error);
        }
    }
    async listTagsForNode(nodeId) {
        try {
            return this.apiService.tagsApi.listTagsForNode(nodeId);
        }
        catch (error) {
            console.error(error);
            return null;
        }
    }
    async listTags(params) {
        try {
            return this.apiService.tagsApi.listTags(params);
        }
        catch (error) {
            console.error(error);
            return null;
        }
    }
    async deleteTagsByTagName(tagName) {
        try {
            const response = await this.listTags({ tag: tagName, matching: true });
            const tagIds = response.list.entries.map((entry) => entry.entry.id);
            await this.deleteTags(tagIds);
        }
        catch (error) {
            console.error(error);
        }
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const LOWER_CASE_ALPHA = 'helloworld';
function generateRandomCharset(length = 8, charSet) {
    let text = '';
    for (let i = 0; i < length; i++) {
        text += charSet.charAt(Math.floor(Math.random() * charSet.length));
    }
    return text;
}
class UserModel {
    firstName = generateRandomCharset(7, LOWER_CASE_ALPHA);
    lastName = generateRandomCharset(7, LOWER_CASE_ALPHA);
    password = generateRandomCharset(7, LOWER_CASE_ALPHA);
    email;
    username;
    idIdentityService;
    type = 'enterprise';
    tenantId;
    company;
    id;
    constructor(details = {}) {
        const EMAIL_DOMAIN = 'alfresco';
        this.firstName = details.firstName ?? this.firstName;
        this.lastName = details.lastName ?? this.lastName;
        const USER_IDENTIFY = `${this.firstName}${this.lastName}.${generateRandomCharset(7, LOWER_CASE_ALPHA)}`;
        this.password = details.password ?? this.password;
        this.email = details.email ?? `${USER_IDENTIFY}@${EMAIL_DOMAIN}.com`;
        this.username = details.username ?? USER_IDENTIFY;
        this.idIdentityService = details.idIdentityService ?? this.idIdentityService;
        this.type = details.type ?? this.type;
        this.tenantId = details.tenantId ?? this.tenantId;
        this.company = details.company ?? this.company;
        this.id = details.id ?? this.id;
    }
    get fullName() {
        return `${this.firstName ?? ''} ${this.lastName ?? ''}`;
    }
}

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const test = test$1.extend({
    personalFiles: async ({ page }, use) => {
        await use(new PersonalFilesPage(page));
    },
    nodesPage: async ({ page }, use) => {
        await use(new NodesPage(page));
    },
    recentFilesPage: async ({ page }, use) => {
        await use(new RecentFilesPage(page));
    },
    sharedPage: async ({ page }, use) => {
        await use(new SharedPage(page));
    },
    searchPage: async ({ page }, use) => {
        await use(new SearchPage(page));
    },
    favoritePage: async ({ page }, use) => {
        await use(new FavoritesPage(page));
    },
    favoritesLibrariesPage: async ({ page }, use) => {
        await use(new FavoritesLibrariesPage(page));
    },
    trashPage: async ({ page }, use) => {
        await use(new TrashPage(page));
    },
    loginPage: async ({ page }, use) => {
        await use(new LoginPage(page));
    },
    // eslint-disable-next-line no-empty-pattern
    fileAction: async ({}, use) => {
        await use(await FileActionsApi.initialize(users.hruser.username));
    },
    // eslint-disable-next-line no-empty-pattern
    shareAction: async ({}, use) => {
        await use(await SharedLinksApi.initialize(users.hruser.username));
    },
    // eslint-disable-next-line no-empty-pattern
    favoritesPageAction: async ({}, use) => {
        await use(await FavoritesPageApi.initialize(users.hruser.username));
    },
    // eslint-disable-next-line no-empty-pattern
    nodesApiAction: async ({}, use) => {
        await use(await NodesApi.initialize(users.admin.username, users.admin.password));
    },
    // eslint-disable-next-line no-empty-pattern
    sitesApiAction: async ({}, use) => {
        await use(await SitesApi.initialize(users.hruser.username));
    },
    myLibrariesPage: async ({ page }, use) => {
        await use(new MyLibrariesPage(page));
    },
    favoriteLibrariesPage: async ({ page }, use) => {
        await use(new FavoritesLibrariesPage(page));
    }
});

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const random$1 = Utils.random();
// ----- files -----
const consumerContextMenu = ['Share', 'Download', 'View', 'Favorite', 'Copy', 'Manage Versions'];
const consumerFavContextMenu = ['Share', 'Download', 'View', 'Remove Favorite', 'Copy', 'Manage Versions'];
const consumerSharedContextMenu = ['Shared Link Settings', 'Download', 'View', 'Favorite', 'Copy', 'Manage Versions'];
const consumerSharedFavContextMenu = ['Shared Link Settings', 'Download', 'View', 'Remove Favorite', 'Copy', 'Manage Versions'];
const consumerToolbarPrimary = ['Share', 'Download', 'View', 'View Details', 'More Actions'];
const consumerSharedToolbarPrimary = ['Shared Link Settings', 'Download', 'View', 'View Details', 'More Actions'];
const searchConsumerToolbarPrimary = ['Share', 'Download', 'View', 'View Details', 'More Actions'];
const searchConsumerSharedToolbarPrimary = ['Shared Link Settings', 'Download', 'View', 'View Details', 'More Actions'];
const consumerToolbarMore = ['Favorite', 'Copy', 'Manage Versions'];
const consumerFavToolbarMore = ['Remove Favorite', 'Copy', 'Manage Versions'];
const collaboratorToolbarPrimary = ['Shared Link Settings', 'Download', 'View', 'View Details', 'More Actions'];
const collaboratorEditRowToolbarMore = [
    'Edit Offline',
    'Upload New Version',
    'Remove Favorite',
    'Copy',
    'Manage Versions',
    'Edit Aspects',
    'Permissions'
];
const favoritesCollaboratorToolbarMore = ['Upload New Version', 'Remove Favorite', 'Move', 'Copy', 'Delete', 'Manage Versions'];
const collaboratorSharedToolbarPrimary = [
    'Activate full-screen mode',
    'Shared Link Settings',
    'Download',
    'Print',
    'View Details',
    'More Actions'
];
const collaboratorDocToolbarMore = [
    'Edit in Microsoft Office™',
    'Edit Offline',
    'Upload New Version',
    'Remove Favorite',
    'Copy',
    'Manage Versions',
    'Edit Aspects',
    'Permissions'
];
const collaboratorLockCurrentUserToolbarMore = ['Cancel Editing', 'Upload New Version', 'Remove Favorite', 'Copy', 'Manage Versions'];
const collaboratorLockOtherUserToolbarMore = ['Cancel Editing', 'Remove Favorite', 'Move', 'Copy', 'Delete', 'Manage Versions', 'Permissions'];
const collaboratorLockOtherUserSearchToolbarMore = ['Cancel Editing', 'Remove Favorite', 'Copy', 'Manage Versions', 'Permissions'];
// ---- VIEWER ----
const consumerViewerSharedToolbarPrimary = ['Activate full-screen mode', 'Shared Link Settings', 'Download', 'Print', 'View Details', 'More Actions'];
const consumerViewerToolbarPrimary = ['Activate full-screen mode', 'Share', 'Download', 'Print', 'View Details', 'More Actions'];
const consumerViewerFavToolbarMore = ['Remove Favorite', 'Copy', 'Manage Versions'];
const consumerViewerToolbarMore = ['Favorite', 'Copy', 'Manage Versions'];
// ---- FAVORITES workarounds ----
const favoritesConsumerToolbarMore = ['Upload New Version', 'Remove Favorite', 'Move', 'Copy', 'Delete', 'Manage Versions'];
const favoritesConsumerContextMenu = [
    'Share',
    'Download',
    'View',
    'Upload New Version',
    'Remove Favorite',
    'Move',
    'Copy',
    'Delete',
    'Manage Versions'
];
const favoritesConsumerSharedContextMenu = [
    'Shared Link Settings',
    'Download',
    'View',
    'Upload New Version',
    'Remove Favorite',
    'Move',
    'Copy',
    'Delete',
    'Manage Versions'
];
// ---- SHARED FILES workaround ----
const sharedConsumerToolbarMore = ['Upload New Version', 'Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerLockedToolbarMore = ['Cancel Editing', 'Upload New Version', 'Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerFavToolbarMore = ['Upload New Version', 'Remove Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerFavLockedToolbarMore = ['Cancel Editing', 'Upload New Version', 'Remove Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerContextMenu = ['Shared Link Settings', 'Download', 'View', 'Upload New Version', 'Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerLockedContextMenu = [
    'Shared Link Settings',
    'Download',
    'View',
    'Cancel Editing',
    'Upload New Version',
    'Favorite',
    'Copy',
    'Manage Versions'
];
const sharedConsumerFavContextMenu = ['Shared Link Settings', 'Download', 'View', 'Upload New Version', 'Remove Favorite', 'Copy', 'Manage Versions'];
const sharedConsumerFavLockedContextMenu = [
    'Shared Link Settings',
    'Download',
    'View',
    'Cancel Editing',
    'Upload New Version',
    'Remove Favorite',
    'Copy',
    'Manage Versions'
];
const fileDocx = {
    name: `file-${random$1}-docx.docx`,
    description: 'file not shared, not fav, office, not locked',
    contextMenu: consumerContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const fileDocxFav = {
    name: `file-${random$1}-docx-fav.docx`,
    description: 'file not shared, fav, office, not locked',
    contextMenu: consumerFavContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerContextMenu,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const file = {
    name: `file-${random$1}.txt`,
    description: 'file not shared, not fav, not office, not locked',
    contextMenu: consumerContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const fileFav = {
    name: `file-${random$1}-fav.txt`,
    description: 'file not shared, fav, not office, not locked',
    contextMenu: consumerFavContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerContextMenu,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const fileDocxShared = {
    name: `file-${random$1}-docx-shared.docx`,
    description: 'file shared, not fav, office, not locked',
    contextMenu: consumerSharedContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    sharedToolbarMore: sharedConsumerToolbarMore,
    sharedContextMenu: sharedConsumerContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileDocxSharedFav = {
    name: `file-${random$1}-docx-shared-fav.docx`,
    description: 'file shared, fav, office, not locked',
    contextMenu: consumerSharedFavContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerSharedContextMenu,
    sharedToolbarMore: sharedConsumerFavToolbarMore,
    sharedContextMenu: sharedConsumerFavContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileShared = {
    name: `file-${random$1}-shared.txt`,
    description: 'file shared, not fav, not office, not locked',
    contextMenu: consumerSharedContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    sharedToolbarMore: sharedConsumerToolbarMore,
    sharedContextMenu: sharedConsumerContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileSharedFav = {
    name: `file-${random$1}-shared-fav.txt`,
    description: 'file shared, fav, not office, not locked',
    contextMenu: consumerSharedFavContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerSharedContextMenu,
    sharedToolbarMore: sharedConsumerFavToolbarMore,
    sharedContextMenu: sharedConsumerFavContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileLocked = {
    name: `file-${random$1}-locked.txt`,
    description: 'file not shared, not fav, not office, locked',
    contextMenu: consumerContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const fileFavLocked = {
    name: `file-${random$1}-fav-locked.txt`,
    description: 'file not shared, fav, not office, locked',
    contextMenu: consumerFavContextMenu,
    toolbarPrimary: consumerToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerContextMenu,
    searchToolbarPrimary: searchConsumerToolbarPrimary
};
const fileSharedLocked = {
    name: `file-${random$1}-shared-locked.txt`,
    description: 'file shared, not fav, not office, locked',
    contextMenu: consumerSharedContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerToolbarMore,
    sharedToolbarMore: sharedConsumerLockedToolbarMore,
    sharedContextMenu: sharedConsumerLockedContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileSharedFavLocked = {
    name: `file-${random$1}-shared-fav-locked.txt`,
    description: 'file shared, fav, not office, locked',
    contextMenu: consumerSharedFavContextMenu,
    toolbarPrimary: consumerSharedToolbarPrimary,
    toolbarMore: consumerFavToolbarMore,
    viewerToolbarPrimary: consumerViewerSharedToolbarPrimary,
    viewerToolbarMore: consumerViewerFavToolbarMore,
    favoritesToolbarMore: favoritesConsumerToolbarMore,
    favoritesContextMenu: favoritesConsumerSharedContextMenu,
    sharedToolbarMore: sharedConsumerFavLockedToolbarMore,
    sharedContextMenu: sharedConsumerFavLockedContextMenu,
    searchToolbarPrimary: searchConsumerSharedToolbarPrimary
};
const fileGranularPermission = `file-${random$1}-granular.txt`;
const fileLockedByUser = `file-${random$1}-my-locked.txt`;
// ---- folders ---
const consumerFolderContextMenu = ['Download', 'Favorite', 'Copy'];
const consumerFolderToolbarPrimary = ['Download', 'View Details', 'More Actions'];
const consumerFolderToolbarMore = ['Favorite', 'Copy'];
const searchConsumerFolderToolbarPrimary = ['Download', 'View Details', 'More Actions'];
const consumerFolderFavContextMenu = ['Download', 'Remove Favorite', 'Copy'];
const consumerFolderFavToolbarMore = ['Remove Favorite', 'Copy'];
// ---- FAVORITES workarounds ----
const favoritesConsumerFolderContextMenu = ['Download', 'Edit', 'Remove Favorite', 'Move', 'Copy', 'Delete'];
const favoritesConsumerFolderToolbarMore = ['Edit', 'Remove Favorite', 'Move', 'Copy', 'Delete'];
const folder = {
    name: `folder-${random$1}`,
    description: 'folder not favorite',
    contextMenu: consumerFolderContextMenu,
    toolbarPrimary: consumerFolderToolbarPrimary,
    toolbarMore: consumerFolderToolbarMore,
    searchToolbarPrimary: searchConsumerFolderToolbarPrimary
};
const folderFav = {
    name: `folder-fav-${random$1}`,
    description: 'folder favorite',
    contextMenu: consumerFolderFavContextMenu,
    toolbarPrimary: consumerFolderToolbarPrimary,
    toolbarMore: consumerFolderFavToolbarMore,
    favoritesContextMenu: favoritesConsumerFolderContextMenu,
    favoritesToolbarMore: favoritesConsumerFolderToolbarMore,
    searchToolbarPrimary: searchConsumerFolderToolbarPrimary
};
const folderFav2 = {
    name: `folder-fav-2-${random$1}`,
    description: 'folder 2 favorite'
};
// ---- multiple selection ---
const multipleSelContextMenu$1 = ['Download', 'Favorite', 'Copy'];
const multipleSelAllFavContextMenu = ['Download', 'Remove Favorite', 'Copy'];
const multipleSelToolbarPrimary$1 = ['Download', 'View Details', 'More Actions'];
const multipleSelToolbarMore$1 = ['Favorite', 'Copy'];
const multipleSelAllFavToolbarMore = ['Remove Favorite', 'Copy'];
const searchMultipleSelToolbarPrimary = ['Download', 'View Details', 'More Actions'];
// ---- FAVORITES workarounds ----
const favoritesMultipleSelContextMenu = ['Download', 'Favorite', 'Move', 'Copy', 'Delete'];
const favoritesMultipleSelToolbarMore = ['Favorite', 'Move', 'Copy', 'Delete'];
const favoritesMultipleSelAllFavContextMenu = ['Download', 'Remove Favorite', 'Move', 'Copy', 'Delete'];
const favoritesMultipleSelAllFavToolbarMore = ['Remove Favorite', 'Move', 'Copy', 'Delete'];
const multipleSel = {
    contextMenu: multipleSelContextMenu$1,
    toolbarPrimary: multipleSelToolbarPrimary$1,
    toolbarMore: multipleSelToolbarMore$1,
    favoritesContextMenu: favoritesMultipleSelContextMenu,
    favoritesToolbarMore: favoritesMultipleSelToolbarMore,
    searchToolbarPrimary: searchMultipleSelToolbarPrimary
};
const multipleSelAllFav = {
    contextMenu: multipleSelAllFavContextMenu,
    toolbarPrimary: multipleSelToolbarPrimary$1,
    toolbarMore: multipleSelAllFavToolbarMore,
    favoritesContextMenu: favoritesMultipleSelAllFavContextMenu,
    favoritesToolbarMore: favoritesMultipleSelAllFavToolbarMore,
    searchToolbarPrimary: searchMultipleSelToolbarPrimary
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const random = Utils.random();
const multipleSelToolbarPrimary = ['Download', 'View Details', 'More Actions'];
// ---- folders ---
const folderContextMenu = ['Download', 'Edit', 'Favorite', 'Move', 'Copy', 'Delete', 'Edit Aspects', 'Permissions', 'Manage Rules'];
const folderFavContextMenu = ['Download', 'Edit', 'Remove Favorite', 'Move', 'Copy', 'Delete', 'Edit Aspects', 'Permissions', 'Manage Rules'];
const folderToolbarMore = ['Edit', 'Favorite', 'Move', 'Copy', 'Delete', 'Edit Aspects', 'Permissions', 'Manage Rules'];
const folderFavToolbarMore = ['Edit', 'Remove Favorite', 'Move', 'Copy', 'Delete', 'Edit Aspects', 'Permissions', 'Manage Rules'];
const folderFile = {
    name: `folderActions-${random}`,
    description: 'folder not favorite',
    contextMenu: folderContextMenu,
    toolbarPrimary: multipleSelToolbarPrimary,
    toolbarMore: folderToolbarMore
};
const folderFavFile = {
    name: `folderActions-fav-${random}`,
    contextMenu: folderFavContextMenu,
    toolbarPrimary: multipleSelToolbarPrimary,
    toolbarMore: folderFavToolbarMore
};
// ---- multiple selection ---
const multipleSelContextMenu = ['Download', 'Favorite', 'Move', 'Copy', 'Delete'];
const multipleSelToolbarMore = ['Favorite', 'Move', 'Copy', 'Delete'];
const multipleSelFile = {
    contextMenu: multipleSelContextMenu,
    toolbarPrimary: multipleSelToolbarPrimary,
    toolbarMore: multipleSelToolbarMore
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
const TEST_FILES = {
    DOCX: {
        path: resolve(__dirname, 'file-docx.docx'),
        name: 'file-docx',
        data: 'Lorem ipsum dolor sit amet'
    },
    DOCX2: {
        path: resolve(__dirname, 'file2-docx.docx'),
        name: 'file2-docx',
        data: 'Lorem ipsum dolor sit amet'
    },
    PDF: {
        path: resolve(__dirname, 'file-pdf.pdf'),
        name: 'file-pdf',
        extension: 'pdf',
        data: 'Lorem ipsum dolor sit amet'
    },
    FILE_UNSUPPORTED: {
        path: resolve(__dirname, 'file_unsupported.3DS'),
        name: 'file_unsupported.3DS',
        data: 'Lorem ipsum dolor sit amet'
    },
    PDF_PROTECTED: {
        path: resolve(__dirname, 'file-pdf-protected.pdf'),
        name: 'file-pdf-protected',
        data: 'Lorem ipsum dolor sit amet',
        password: '0000'
    },
    XLSX: {
        path: resolve(__dirname, 'file-xlsx.xlsx'),
        name: 'file-xlsx',
        data: 'Lorem ipsum dolor sit amet'
    },
    XLSX2: {
        path: resolve(__dirname, 'file2-xlsx.xlsx'),
        name: 'file2-xlsx',
        data: 'Lorem ipsum dolor sit amet'
    },
    JPG_FILE: {
        path: resolve(__dirname, 'file-jpg.jpg'),
        name: 'file-jpg'
    },
    JPG_FILE_1MB: {
        path: resolve(__dirname, 'file-jpg-1mb.jpg'),
        name: 'file-jpg-1mb'
    },
    PNG_FILE: {
        path: resolve(__dirname, 'file-png.png'),
        name: 'file-png'
    },
    GIF_FILE: {
        path: resolve(__dirname, 'file-gif.gif'),
        name: 'file-gif'
    },
    PPTX_FILE: {
        path: resolve(__dirname, 'file-pptx.pptx'),
        name: 'file-pptx'
    },
    MP3_FILE: {
        path: resolve(__dirname, 'file-mp3.mp3'),
        name: 'file-mp3'
    },
    MP4_FILE: {
        path: resolve(__dirname, 'file-mp4.mp4'),
        name: 'file-mp4'
    },
    WEBM_FILE: {
        path: resolve(__dirname, 'file-webm.webm'),
        name: 'file-webm'
    },
    PDF_PROTECTED2: {
        path: resolve(__dirname, 'protected.pdf'),
        name: 'file-protected',
        data: 'Lorem ipsum dolor sit amet',
        password: '0000'
    }
};

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Generated bundle index. Do not edit.
 */

export { APP_ROUTES, AcaHeader, ActionType, ActionTypes, ActionsDropdownComponent, AdfConfirmDialogComponent, AdfDeleteTrashComponent, AdfFolderDialogComponent, AdfInfoDrawerComponent, AdfLibraryDialogComponent, ApiClientFactory, BaseComponent, BasePage, Breadcrumb, CategoriesApi, Comparator, ConditionComponent, ConditionsTypes, ContentNodeSelectorDialog, CreateFromTemplateDialogComponent, DataTableComponent, DateTimePicker, EditDialog, ErrorComponent, FavoritesLibrariesPage, FavoritesPage, FavoritesPageApi, Field, FileActionsApi, GenericLogger, LinkRulesDialog, LogLevelsEnum, LoginPage, ManageRules, ManageRulesDialogComponent, ManageVersionsDialog, MatMenuComponent, MyLibrariesPage, NodesApi, NodesPage, PaginationActionsType, PaginationComponent, PasswordOverlayDialogComponent, Person, PersonalFilesPage, QueriesApi, RecentFilesPage, RulesApi, SIDEBAR_LABELS, SITE_ROLES, SITE_VISIBILITY, SearchFilters, SearchFiltersCategories, SearchFiltersDate, SearchFiltersLocation, SearchFiltersLogic, SearchFiltersProperties, SearchFiltersTags, SearchInputComponent, SearchOverlayComponent, SearchPage, SearchPageApi, SearchSortingPicker, ShareDialogComponent, SharedLinksApi, SharedPage, SidenavComponent, SitesApi, SnackBarComponent, SpinnerComponent, TEST_FILES, TagsApi, ToolbarComponent, TrashPage, TrashcanApi, UploadDialog, UploadNewVersionDialog, UserModel, Utils, ViewerComponent, ViewerOverlayDialogComponent, collaboratorDocToolbarMore, collaboratorEditRowToolbarMore, collaboratorLockCurrentUserToolbarMore, collaboratorLockOtherUserSearchToolbarMore, collaboratorLockOtherUserToolbarMore, collaboratorSharedToolbarPrimary, collaboratorToolbarPrimary, errorColor, errorStrings, favoritesCollaboratorToolbarMore, file, fileDocx, fileDocxFav, fileDocxShared, fileDocxSharedFav, fileFav, fileFavLocked, fileGranularPermission, fileLocked, fileLockedByUser, fileShared, fileSharedFav, fileSharedFavLocked, fileSharedLocked, flattenNodeContentTree, folder, folderFav, folderFav2, folderFavFile, folderFile, getExcludedTestsRegExpArray, getGlobalConfig, getUserState, infoColor, libraryErrors, logColor, logLevels, multipleSel, multipleSelAllFav, multipleSelFile, paths, random$1 as random, test, testEmailDomain, timeouts, users, waitForApi, warnColor };
//# sourceMappingURL=alfresco-aca-playwright-shared.mjs.map
